<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

require_once("Persons.php");

class Employees extends Persons
{
	public function __construct()
	{
		parent::__construct('employees');

		$this->load->library('item_lib');
		$config_data = array(
			'value' => 25
		);

		$this->db->where('key', 'lines_per_page');
		$success = $this->db->update('ospos_app_config', $config_data);
	}
	
	public function index()
	{
		$data['table_headers'] = $this->xss_clean(get_people_manage_table_headers());

		$this->load->view('people/manage', $data);
	}
	
	/*
	Returns employee table data rows. This will be called with AJAX.
	*/
	public function search()
	{
		$search = $this->input->get('search');
		$limit  = $this->input->get('limit');
		$offset = $this->input->get('offset');
		$sort   = $this->input->get('sort');
		$order  = $this->input->get('order');

		$employees = $this->Employee->search($search, $limit, $offset, $sort, $order);
		$total_rows = $this->Employee->get_found_rows($search);

		$data_rows = array();
		foreach($employees->result() as $person)
		{
			$data_rows[] = get_person_data_row($person, $this);
		}

		$data_rows = $this->xss_clean($data_rows);

		echo json_encode(array('total' => $total_rows, 'rows' => $data_rows));
	}
	
	/*
	Gives search suggestions based on what is being searched for
	*/
	public function suggest()
	{
		$suggestions = $this->xss_clean($this->Employee->get_search_suggestions($this->input->get('term'), TRUE));
		echo json_encode($suggestions);
	}

	public function suggest_search()
	{
		$suggestions = $this->xss_clean($this->Employee->get_search_suggestions($this->input->post('term')));

		echo json_encode($suggestions);
	}
	
	/*
	Loads the employee edit form
	*/
	public function view($employee_id = -1)
	{
		$person_info = $this->Employee->get_info($employee_id);
		foreach(get_object_vars($person_info) as $property => $value)
		{
			$person_info->$property = $this->xss_clean($value);
		}
		$data['person_info'] = $person_info;

		$modules = array();
		foreach($this->Module->get_all_modules()->result() as $module)
		{
			$module->module_id = $this->xss_clean($module->module_id);
			$module->grant = $this->xss_clean($this->Employee->has_grant($module->module_id, $person_info->person_id));
			
			$modules[] = $module;
		}
		$data['all_modules'] = $modules;

		$permissions = array();
		foreach($this->Module->get_all_subpermissions()->result() as $permission)
		{
			$permission->module_id = $this->xss_clean($permission->module_id);
			$permission->permission_id = $this->xss_clean($permission->permission_id);
			$permission->grant = $this->xss_clean($this->Employee->has_grant($permission->permission_id, $person_info->person_id));
			
			$permissions[] = $permission;
		}
		$data['all_subpermissions'] = $permissions;

		$this->load->view("employees/form", $data);
	}
	
	/*
	Inserts/updates an employee
	*/
	public function save($employee_id = -1)
	{
		$person_data = array(
			'first_name' => $this->input->post('first_name'),
			'last_name' => $this->input->post('last_name'),
			'gender' => $this->input->post('gender'),
			'email' => $this->input->post('email'),
			'phone_number' => $this->input->post('phone_number'),
			'address_1' => $this->input->post('address_1'),
			'address_2' => $this->input->post('address_2'),
			'city' => $this->input->post('city'),
			'state' => $this->input->post('state'),
			'zip' => $this->input->post('zip'),
			'country' => $this->input->post('country'),
			'comments' => $this->input->post('comments'),
		);
		$grants_data = $this->input->post('grants') != NULL ? $this->input->post('grants') : array();
		
		//Password has been changed OR first time password set
		if($this->input->post('password') != '')
		{
			$employee_data = array(
				'username' => $this->input->post('username'),
				'password' => password_hash($this->input->post('password'), PASSWORD_DEFAULT),
				'hash_version' => 2
			);
		}
		else //Password not changed
		{
			$employee_data = array('username' => $this->input->post('username'));
		}
		
		if($this->Employee->save_employee($person_data, $employee_data, $grants_data, $employee_id))
		{
			$person_data = $this->xss_clean($person_data);
			$employee_data = $this->xss_clean($employee_data);

			//New employee
			if($employee_id == -1)
			{
				echo json_encode(array('success' => TRUE, 'message' => $this->lang->line('employees_successful_adding').' '.
								$person_data['first_name'].' '.$person_data['last_name'], 'id' => $employee_data['person_id']));
			}
			else //Existing employee
			{
				echo json_encode(array('success' => TRUE, 'message' => $this->lang->line('employees_successful_updating').' '.
								$person_data['first_name'].' '.$person_data['last_name'], 'id' => $employee_id));
			}
		}
		else//failure
		{
			$person_data = $this->xss_clean($person_data);

			echo json_encode(array('success' => FALSE, 'message' => $this->lang->line('employees_error_adding_updating').' '.
							$person_data['first_name'].' '.$person_data['last_name'], 'id' => -1));
		}
	}
	
	/*
	This deletes employees from the employees table
	*/
	public function delete()
	{
		$employees_to_delete = $this->xss_clean($this->input->post('ids'));

		if($this->Employee->delete_list($employees_to_delete))
		{
			echo json_encode(array('success' => TRUE,'message' => $this->lang->line('employees_successful_deleted').' '.
							count($employees_to_delete).' '.$this->lang->line('employees_one_or_multiple')));
		}
		else
		{
			echo json_encode(array('success' => FALSE,'message' => $this->lang->line('employees_cannot_be_deleted')));
		}
	}

	public function sellers()
	{	
		
		$data = array();

		$this->load->view('employees/sellers', $data);
	}

	public function list_sellers()
	{	
		
		$fecha_ini = $this->input->post('fecha_ini');
		$fecha_fin = $this->input->post('fecha_fin');

		$sales = $this->Employee->get_seller_percents($fecha_ini, $fecha_fin);
		$data = array();
		$data['sales'] = array();
		$data['sales'] = $sales;
		$data['fecha_ini'] = $fecha_ini;
		$data['fecha_fin'] = $fecha_fin;
		$data['title'] = "COMISIONES DE VENDEDORES";
		$data['subtitle'] = 'Desde '.$fecha_ini.' hasta '.$fecha_fin;
		$this->load->view('employees/list_sellers', $data);
	}

	public function list_sellers_detail()
	{	
		
		$seller_id = $this->input->get('seller_id');
		$fecha_ini = $this->input->get('fecha_ini');
		$fecha_fin = $this->input->get('fecha_fin');
		$ver_ganancia = $this->input->get('ver_ganancia');
		
		
		$sales = $this->Employee->get_seller_detail($seller_id,$fecha_ini, $fecha_fin);
		$data = array();

		$data['seller'] = $seller_id;
		$seller_info = $this->Employee->get_info($data['seller']);
		$data['seller_name'] = $seller_info->first_name  . ' ' . $seller_info->last_name;

		$data['sales'] = array();
		$data['sales'] = $sales;
		$data['fecha_ini'] = $fecha_ini;
		$data['fecha_fin'] = $fecha_fin;
		$data['ver_ganancia'] = $ver_ganancia;

		$data['title'] = "COMISIONES POR VENTAS";
		$data['subtitle'] = 'Vendedor: '.$data['seller_name'].' Desde '.$fecha_ini.' hasta '.$fecha_fin;
		$this->load->view('employees/list_sellers_detail', $data);
	}
	
	public function list_sale_detail()
	{	
		
		$sale_id = $this->input->get('sale_id');
		$fecha_ini = $this->input->get('fecha_ini');
		$fecha_fin = $this->input->get('fecha_fin');
		$seller_id = $this->input->get('seller_id');
		$customer = $this->input->get('customer');
		$sale_date = $this->input->get('sale_date');
		$seller_name = $this->input->get('seller_name');
		$ver_ganancia = $this->input->get('ver_ganancia');
		//echo "sale ".$sale_id;
		//die(); 

		$sales = $this->Employee->get_sale_detail($sale_id);
		$data = array();
		$data['sales'] = array();
		$data['sales'] = $sales;
		$data['seller_id'] = $seller_id;
		$data['fecha_ini'] = $fecha_ini;
		$data['fecha_fin'] = $fecha_fin;
		$data['ver_ganancia'] = $ver_ganancia;
		$data['title'] = "CONTROL DE VENTA Nro:".$sale_id. " FECHA:".$sale_date;
		$data['subtitle'] = 'Vendedor:'.$seller_name.' Cliente:'.$customer;
		$this->load->view('employees/list_sale_detail', $data);
	}

	/*JORNALEROS*/
	public function salary()
	{	
		
		$data = array();

		$asalariados = $this->Employee->get_jornaleros();

	  
	   	$data['asalariados']=$asalariados;

		$this->load->view('employees/salary', $data);
	}
	public function add_debit_credit()
	{
		$employee_id = $this->input->get('employee_id');
		$description = $this->input->get('description');
		$debit_amount = $this->input->get('debit_amount');
		$credit_amount = $this->input->get('credit_amount');

		$item_data = array(
			'employee_id' => $employee_id,
			'description' => $description,
			'debit_amount' => $debit_amount,
			'credit_amount' => $credit_amount
		);

		$this->db->insert('ospos_employees_debit_credit', $item_data);
		$data['success']="Se ha agregado el débito/crédito ".$description;
		
		$debitos_creditos = $this->Employee->get_debitos_creditos($employee_id,date('Y-m-d'),date('Y-m-d'));
		
		$name = $this->Person->get_name($employee_id);
	  	$data['name'] = $name;
	  	$data['employee_id'] = $employee_id;
	  	$data['debitos_creditos'] = array();	
	   	$data['debitos_creditos']=$debitos_creditos;
	   	$data['fecha_ini']=date('Y-m-d');
	   	$data['fecha_fin']=date('Y-m-d');
		
		$this->load->view('employees/debit_credit', $data);
	}
	public function list_debit_credit()
	{
		$employee_id = $this->input->get('employee_id');
		$fecha_ini = $this->input->get('fecha_ini');
		$fecha_fin = $this->input->get('fecha_fin');

		$debitos_creditos = $this->Employee->get_debitos_creditos($employee_id,$fecha_ini,$fecha_fin);
		$name = $this->Person->get_name($employee_id);
	  	$data['name'] = $name;
	  	$data['employee_id'] = $employee_id;
	   	$data['debitos_creditos']=$debitos_creditos;
		$data['fecha_ini']=$fecha_ini;
	   	$data['fecha_fin']=$fecha_fin;
		$this->load->view('employees/debit_credit', $data);
	}
	/*FIN JORNALEROS*/


}
?>