<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

require_once("Secure_Controller.php");

class Items extends Secure_Controller
{
	public function __construct()
	{
		parent::__construct('items');

		$this->load->library('item_lib');

		$this->load->library('item_lib');
		$config_data = array(
			'value' => 25
		);

		$this->db->where('key', 'lines_per_page');
		$success = $this->db->update('ospos_app_config', $config_data);
	}
	
	public function index()
	{
		$data['table_headers'] = $this->xss_clean(get_items_manage_table_headers());
		
		$data['stock_location'] = $this->xss_clean($this->item_lib->get_item_location());
		$data['stock_locations'] = $this->xss_clean($this->Stock_location->get_allowed_locations());

		// filters that will be loaded in the multiselect dropdown
		$data['filters'] = array('empty_upc' => $this->lang->line('items_empty_upc_items'),
			'low_inventory' => $this->lang->line('items_low_inventory_items'),
			'is_serialized' => $this->lang->line('items_serialized_items'),
			'no_description' => $this->lang->line('items_no_description_items'),
			'search_custom' => $this->lang->line('items_search_custom_items'),
			'is_deleted' => $this->lang->line('items_is_deleted'));

		$this->load->view('items/manage', $data);
	}

	/*
	Returns Items table data rows. This will be called with AJAX.
	*/
	public function search()
	{
		$search = $this->input->get('search');
		$limit = $this->input->get('limit');
		$offset = $this->input->get('offset');
		$sort = $this->input->get('sort');
		$order = $this->input->get('order');

		$this->item_lib->set_item_location($this->input->get('stock_location'));

		$filters = array('start_date' => $this->input->get('start_date'),
						'end_date' => $this->input->get('end_date'),
						'stock_location_id' => $this->item_lib->get_item_location(),
						'empty_upc' => FALSE,
						'low_inventory' => FALSE, 
						'is_serialized' => FALSE,
						'no_description' => FALSE,
						'search_custom' => FALSE,
						'is_deleted' => FALSE);
		
		// check if any filter is set in the multiselect dropdown
		$filledup = array_fill_keys($this->input->get('filters'), TRUE);
		$filters = array_merge($filters, $filledup);

		$items = $this->Item->search($search, $filters, $limit, $offset, $sort, $order);
		$total_rows = $this->Item->get_found_rows($search, $filters);

		$data_rows = array();
		foreach($items->result() as $item)
		{
			$data_rows[] = $this->xss_clean(get_item_data_row($item, $this));
		}

		echo json_encode(array('total' => $total_rows, 'rows' => $data_rows));
	}
	
	public function pic_thumb($pic_id)
	{
		$this->load->helper('file');
		$this->load->library('image_lib');
		$base_path = './uploads/item_pics/' . $pic_id;
		$images = glob($base_path . '.*');
		if(sizeof($images) > 0)
		{
			$image_path = $images[0];
			$ext = pathinfo($image_path, PATHINFO_EXTENSION);
			$thumb_path = $base_path . $this->image_lib->thumb_marker . '.' . $ext;
			if(sizeof($images) < 2)
			{
				$config['image_library'] = 'gd2';
				$config['source_image']  = $image_path;
				$config['maintain_ratio'] = TRUE;
				$config['create_thumb'] = TRUE;
				$config['width'] = 52;
				$config['height'] = 32;
 				$this->image_lib->initialize($config);
 				$image = $this->image_lib->resize();
				$thumb_path = $this->image_lib->full_dst_path;
			}
			$this->output->set_content_type(get_mime_by_extension($thumb_path));
			$this->output->set_output(file_get_contents($thumb_path));
		}
	}

	/*
	Gives search suggestions based on what is being searched for
	*/
	public function suggest_search()
	{
		$suggestions = $this->xss_clean($this->Item->get_search_suggestions($this->input->post_get('term'),
			array('search_custom' => $this->input->post('search_custom'), 'is_deleted' => $this->input->post('is_deleted') != NULL), FALSE));

		echo json_encode($suggestions);
	}

	public function suggest()
	{
		$suggestions = $this->xss_clean($this->Item->get_search_suggestions($this->input->post_get('term'),
			array('search_custom' => FALSE, 'is_deleted' => FALSE), TRUE));

		echo json_encode($suggestions);
	}

	/*
	Gives search suggestions based on what is being searched for
	*/
	public function suggest_category()
	{
		$suggestions = $this->xss_clean($this->Item->get_category_suggestions($this->input->get('term')));

		echo json_encode($suggestions);
	}

	/*
	 Gives search suggestions based on what is being searched for
	*/
	public function suggest_location()
	{
		$suggestions = $this->xss_clean($this->Item->get_location_suggestions($this->input->get('term')));

		echo json_encode($suggestions);
	}
	
	/*
	 Gives search suggestions based on what is being searched for
	*/
	public function suggest_custom()
	{
		$suggestions = $this->xss_clean($this->Item->get_custom_suggestions($this->input->post('term'), $this->input->post('field_no')));

		echo json_encode($suggestions);
	}

	public function get_row($item_ids)
	{
		$item_infos = $this->Item->get_multiple_info(explode(":", $item_ids), $this->item_lib->get_item_location());

		$result = array();
		foreach($item_infos->result() as $item_info)
		{
			$result[$item_info->item_id] = $this->xss_clean(get_item_data_row($item_info, $this));
		}

		echo json_encode($result);
	}

	public function view($item_id = -1)
	{
		$data['item_tax_info'] = $this->xss_clean($this->Item_taxes->get_info($item_id));
		$data['default_tax_1_rate'] = '';
		$data['default_tax_2_rate'] = '';

		$data['next_id'] = $this->Item->get_max_id()+1;
		
		$item_info = $this->Item->get_info($item_id);
		foreach(get_object_vars($item_info) as $property => $value)
		{
			$item_info->$property = $this->xss_clean($value);
		}

		if($item_id == -1)
		{
			$data['default_tax_1_rate'] = $this->config->item('default_tax_1_rate');
			$data['default_tax_2_rate'] = $this->config->item('default_tax_2_rate');
			
			$item_info->receiving_quantity = 0;
			$item_info->reorder_level = 0;
		}

		$data['item_info'] = $item_info;

		$suppliers = array('' => $this->lang->line('items_none'));
		foreach($this->Supplier->get_all()->result_array() as $row)
		{
			$suppliers[$this->xss_clean($row['person_id'])] = $this->xss_clean($row['company_name']);
		}
		$data['suppliers'] = $suppliers;
		$data['selected_supplier'] = $item_info->supplier_id;

		$data['logo_exists'] = $item_info->pic_id != '';
		$images = glob('./uploads/item_pics/' . $item_info->pic_id . '.*');
		$data['image_path'] = sizeof($images) > 0 ? base_url($images[0]) : '';

		$stock_locations = $this->Stock_location->get_undeleted_all()->result_array();
        foreach($stock_locations as $location)
        {
			$location = $this->xss_clean($location);

			$quantity = $this->xss_clean($this->Item_quantity->get_item_quantity($item_id, $location['location_id'])->quantity);
			$quantity = ($item_id == -1) ? 0 : $quantity;
			$location_array[$location['location_id']] = array('location_name' => $location['location_name'], 'quantity' => $quantity);
			$data['stock_locations'] = $location_array;
        }

		$this->load->view('items/form', $data);
	}
    
	public function inventory($item_id = -1)
	{
		$item_info = $this->Item->get_info($item_id);
		foreach(get_object_vars($item_info) as $property => $value)
		{
			$item_info->$property = $this->xss_clean($value);
		}
		$data['item_info'] = $item_info;

        $data['stock_locations'] = array();
        $stock_locations = $this->Stock_location->get_undeleted_all()->result_array();
        foreach($stock_locations as $location)
        {
			$location = $this->xss_clean($location);
			$quantity = $this->xss_clean($this->Item_quantity->get_item_quantity($item_id, $location['location_id'])->quantity);
		
            $data['stock_locations'][$location['location_id']] = $location['location_name'];
            $data['item_quantities'][$location['location_id']] = $quantity;
        }

		$this->load->view('items/form_inventory', $data);
	}
	
	public function count_details($item_id = -1)
	{
		$item_info = $this->Item->get_info($item_id);
		foreach(get_object_vars($item_info) as $property => $value)
		{
			$item_info->$property = $this->xss_clean($value);
		}
		$data['item_info'] = $item_info;

        $data['stock_locations'] = array();
        $stock_locations = $this->Stock_location->get_undeleted_all()->result_array();
        foreach($stock_locations as $location)
        {
			$location = $this->xss_clean($location);
			$quantity = $this->xss_clean($this->Item_quantity->get_item_quantity($item_id, $location['location_id'])->quantity);
		
            $data['stock_locations'][$location['location_id']] = $location['location_name'];
            $data['item_quantities'][$location['location_id']] = $quantity;
        }

		$this->load->view('items/form_count_details', $data);
	}

	public function generate_barcodes($item_ids)
	{
		$this->load->library('barcode_lib');

		$item_ids = explode(':', $item_ids);
		$result = $this->Item->get_multiple_info($item_ids, $this->item_lib->get_item_location())->result_array();
		$config = $this->barcode_lib->get_barcode_config();

		$data['barcode_config'] = $config;

		// check the list of items to see if any item_number field is empty
		foreach($result as &$item)
		{
			$item = $this->xss_clean($item);
			
			// update the UPC/EAN/ISBN field if empty / NULL with the newly generated barcode
			if(empty($item['item_number']) && $this->config->item('barcode_generate_if_empty'))
			{
				// get the newly generated barcode
				$barcode_instance = Barcode_lib::barcode_instance($item, $config);
				$item['item_number'] = $barcode_instance->getData();
				
				$save_item = array('item_number' => $item['item_number']);

				// update the item in the database in order to save the UPC/EAN/ISBN field
				$this->Item->save($save_item, $item['item_id']);
			}
		}
		$data['items'] = $result;

		// display barcodes
		$this->load->view('barcodes/barcode_sheet', $data);
	}

	public function bulk_edit()
	{
		$suppliers = array('' => $this->lang->line('items_none'));
		foreach($this->Supplier->get_all()->result_array() as $row)
		{
			$row = $this->xss_clean($row);

			$suppliers[$row['person_id']] = $row['company_name'];
		}
		$data['suppliers'] = $suppliers;
		$data['allow_alt_description_choices'] = array(
			'' => $this->lang->line('items_do_nothing'), 
			1  => $this->lang->line('items_change_all_to_allow_alt_desc'),
			0  => $this->lang->line('items_change_all_to_not_allow_allow_desc'));

		$data['serialization_choices'] = array(
			'' => $this->lang->line('items_do_nothing'), 
			1  => $this->lang->line('items_change_all_to_serialized'),
			0  => $this->lang->line('items_change_all_to_unserialized'));

		$this->load->view('items/form_bulk', $data);
	}

	public function save($item_id = -1)
	{
		$upload_success = $this->_handle_image_upload();
		$upload_data = $this->upload->data();

		//Save item data
		$item_data = array(
			'name' => $this->input->post('name'),
			'description' => $this->input->post('description'),
			'category' => $this->input->post('category'),
			'supplier_id' => $this->input->post('supplier_id') == '' ? NULL : $this->input->post('supplier_id'),
			'item_number' => $this->input->post('item_number') == '' ? NULL : $this->input->post('item_number'),
			'cost_price' => parse_decimals($this->input->post('cost_price')),
			'unit_price' => parse_decimals($this->input->post('unit_price')),
			'reorder_level' => parse_decimals($this->input->post('reorder_level')),
			'receiving_quantity' => parse_decimals($this->input->post('receiving_quantity')),
			'allow_alt_description' => $this->input->post('allow_alt_description') != NULL,
			'is_serialized' => $this->input->post('is_serialized') != NULL,
			'deleted' => $this->input->post('is_deleted') != NULL,
			'custom1' => $this->input->post('custom1') == NULL ? '' : $this->input->post('custom1'),
			'custom2' => $this->input->post('custom2') == NULL ? '' : $this->input->post('custom2'),
			'custom3' => $this->input->post('custom3') == NULL ? '' : $this->input->post('custom3'),
			'custom4' => $this->input->post('custom4') == NULL ? '' : $this->input->post('custom4'),
			'custom5' => $this->input->post('custom5') == NULL ? '' : $this->input->post('custom5'),
			'custom6' => $this->input->post('custom6') == NULL ? '' : $this->input->post('custom6'),
			'custom7' => $this->input->post('custom7') == NULL ? '' : $this->input->post('custom7'),
			'custom8' => $this->input->post('custom8') == NULL ? '' : $this->input->post('custom8'),
			'custom9' => $this->input->post('custom9') == NULL ? '' : $this->input->post('custom9'),
			'custom10' => $this->input->post('custom10') == NULL ? '' : $this->input->post('custom10')
		);
		
		if(!empty($upload_data['orig_name']))
		{
			// XSS file image sanity check
			if($this->xss_clean($upload_data['raw_name'], TRUE) === TRUE)
			{
				$item_data['pic_id'] = $upload_data['raw_name'];
			}
		}
		
		$employee_id = $this->Employee->get_logged_in_employee_info()->person_id;
		$cur_item_info = $this->Item->get_info($item_id);
		
		if($this->Item->save($item_data, $item_id))
		{
			$success = TRUE;
			$new_item = FALSE;
			//New item
			if($item_id == -1)
			{
				$item_id = $item_data['item_id'];
				$new_item = TRUE;
			}
			
			$items_taxes_data = array();
			$tax_names = $this->input->post('tax_names');
			$tax_percents = $this->input->post('tax_percents');
			$count = count($tax_percents);
			for ($k = 0; $k < $count; ++$k)
			{
				$tax_percentage = parse_decimals($tax_percents[$k]);
				if(is_numeric($tax_percentage))
				{
					$items_taxes_data[] = array('name' => $tax_names[$k], 'percent' => $tax_percentage);
				}
			}
			$success &= $this->Item_taxes->save($items_taxes_data, $item_id);
            
            //Save item quantity
            $stock_locations = $this->Stock_location->get_undeleted_all()->result_array();
            foreach($stock_locations as $location)
            {
                $updated_quantity = parse_decimals($this->input->post('quantity_' . $location['location_id']));
                $location_detail = array('item_id' => $item_id,
                                        'location_id' => $location['location_id'],
                                        'quantity' => $updated_quantity);  
                $item_quantity = $this->Item_quantity->get_item_quantity($item_id, $location['location_id']);
                if($item_quantity->quantity != $updated_quantity || $new_item) 
                {              
	                $success &= $this->Item_quantity->save($location_detail, $item_id, $location['location_id']);
	                
	                $inv_data = array(
	                    'trans_date' => date('Y-m-d H:i:s'),
	                    'trans_items' => $item_id,
	                    'trans_user' => $employee_id,
	                    'trans_location' => $location['location_id'],
	                    'trans_comment' => $this->lang->line('items_manually_editing_of_quantity'),
	                    'trans_inventory' => $updated_quantity - $item_quantity->quantity
	                );

	                $success &= $this->Inventory->insert($inv_data);       
                }                                            
            }

			if($success && $upload_success)
            {
            	$message = $this->xss_clean($this->lang->line('items_successful_' . ($new_item ? 'adding' : 'updating')) . ' ' . $item_data['name']);

            	echo json_encode(array('success' => TRUE, 'message' => $message, 'id' => $item_id));
            }
            else
            {
            	$message = $this->xss_clean($upload_success ? $this->lang->line('items_error_adding_updating') . ' ' . $item_data['name'] : strip_tags($this->upload->display_errors())); 

            	echo json_encode(array('success' => FALSE, 'message' => $message, 'id' => $item_id));
            }
		}
		else//failure
		{
			$message = $this->xss_clean($this->lang->line('items_error_adding_updating') . ' ' . $item_data['name']);
			
			echo json_encode(array('success' => FALSE, 'message' => $message, 'id' => -1));
		}
	}
	
	public function check_item_number()
	{
		$exists = $this->Item->item_number_exists($this->input->post('item_number'), $this->input->post('item_id'));
		echo !$exists ? 'true' : 'false';
	}
	
	private function _handle_image_upload()
	{
		$this->load->helper('directory');

		$map = directory_map('./uploads/item_pics/', 1);

		// load upload library
		$config = array('upload_path' => './uploads/item_pics/',
			'allowed_types' => 'gif|jpg|png',
			'max_size' => '100',
			'max_width' => '640',
			'max_height' => '480',
			'file_name' => sizeof($map) + 1
		);
		$this->load->library('upload', $config);
		$this->upload->do_upload('item_image');           
		
		return strlen($this->upload->display_errors()) == 0 || !strcmp($this->upload->display_errors(), '<p>'.$this->lang->line('upload_no_file_selected').'</p>');
	}

	public function remove_logo($item_id)
	{
		$item_data = array('pic_id' => NULL);
		$result = $this->Item->save($item_data, $item_id);

		echo json_encode(array('success' => $result));
	}

	public function save_inventory($item_id = -1)
	{	
		$employee_id = $this->Employee->get_logged_in_employee_info()->person_id;
		$cur_item_info = $this->Item->get_info($item_id);
        $location_id = $this->input->post('stock_location');
		$inv_data = array(
			'trans_date' => date('Y-m-d H:i:s'),
			'trans_items' => $item_id,
			'trans_user' => $employee_id,
			'trans_location' => $location_id,
			'trans_comment' => $this->input->post('trans_comment'),
			'trans_inventory' => parse_decimals($this->input->post('newquantity'))
		);
		
		$this->Inventory->insert($inv_data);
		
		//Update stock quantity
		$item_quantity = $this->Item_quantity->get_item_quantity($item_id, $location_id);
		$item_quantity_data = array(
			'item_id' => $item_id,
			'location_id' => $location_id,
			'quantity' => $item_quantity->quantity + parse_decimals($this->input->post('newquantity'))
		);

		if($this->Item_quantity->save($item_quantity_data, $item_id, $location_id))
		{
			$message = $this->xss_clean($this->lang->line('items_successful_updating') . ' ' . $cur_item_info->name);
			
			echo json_encode(array('success' => TRUE, 'message' => $message, 'id' => $item_id));
		}
		else//failure
		{
			$message = $this->xss_clean($this->lang->line('items_error_adding_updating') . ' ' . $cur_item_info->name);
			
			echo json_encode(array('success' => FALSE, 'message' => $message, 'id' => -1));
		}
	}

	public function bulk_update()
	{
		$items_to_update = $this->input->post('item_ids');
		$item_data = array();

		foreach($_POST as $key => $value)
		{		
			//This field is nullable, so treat it differently
			if($key == 'supplier_id' && $value != '')
			{	
				$item_data["$key"] = $value;
			}
			elseif($value != '' && !(in_array($key, array('item_ids', 'tax_names', 'tax_percents'))))
			{
				$item_data["$key"] = $value;
			}
		}

		//Item data could be empty if tax information is being updated
		if(empty($item_data) || $this->Item->update_multiple($item_data, $items_to_update))
		{
			$items_taxes_data = array();
			$tax_names = $this->input->post('tax_names');
			$tax_percents = $this->input->post('tax_percents');
			$tax_updated = FALSE;
			$count = count($tax_percents);
			for ($k = 0; $k < $count; ++$k)
			{		
				if(!empty($tax_names[$k]) && is_numeric($tax_percents[$k]))
				{
					$tax_updated = TRUE;
					
					$items_taxes_data[] = array('name' => $tax_names[$k], 'percent' => $tax_percents[$k]);
				}
			}
			
			if($tax_updated)
			{
				$this->Item_taxes->save_multiple($items_taxes_data, $items_to_update);
			}

			echo json_encode(array('success' => TRUE, 'message' => $this->lang->line('items_successful_bulk_edit'), 'id' => $this->xss_clean($items_to_update)));
		}
		else
		{
			echo json_encode(array('success' => FALSE, 'message' => $this->lang->line('items_error_updating_multiple')));
		}
	}

	public function delete()
	{
		$items_to_delete = $this->input->post('ids');

		if($this->Item->delete_list($items_to_delete))
		{
			$message = $this->lang->line('items_successful_deleted') . ' ' . count($items_to_delete) . ' ' . $this->lang->line('items_one_or_multiple');
			echo json_encode(array('success' => TRUE, 'message' => $message));
		}
		else
		{
			echo json_encode(array('success' => FALSE, 'message' => $this->lang->line('items_cannot_be_deleted')));
		}
	}

	/*
	Items import from excel spreadsheet
	*/
	public function excel()
	{
		$name = 'import_items.csv';
		$data = file_get_contents('../' . $name);
		force_download($name, $data);
	}
	
	public function excel_import()
	{
		$this->load->view('items/form_excel_import', NULL);
	}

    public function do_excel_import()
    {
        if($_FILES['file_path']['error'] != UPLOAD_ERR_OK)
        {
            echo json_encode(array('success' => FALSE, 'message' => $this->lang->line('items_excel_import_failed')));
        }
        else
		{
            if(($handle = fopen($_FILES['file_path']['tmp_name'], 'r')) !== FALSE)
            {
                // Skip the first row as it's the table description
                fgetcsv($handle);
                $i = 1;
				
				$failCodes = array();
		
                while(($data = fgetcsv($handle)) !== FALSE)
                {
					// XSS file data sanity check
					$data = $this->xss_clean($data);
					
					if(sizeof($data) >= 23)
					{
	                    $item_data = array(
	                        'name'					=> $data[1],
	                        'description'			=> $data[11],
	                        'category'				=> $data[2],
	                        'cost_price'			=> $data[4],
	                        'unit_price'			=> $data[5],
	                        'reorder_level'			=> $data[10],
	                        'supplier_id'			=> $this->Supplier->exists($data[3]) ? $data[3] : NULL,
	                        'allow_alt_description'	=> $data[12] != '' ? '1' : '0',
	                        'is_serialized'			=> $data[13] != '' ? '1' : '0',
	                        'custom1'				=> $data[14],
	                        'custom2'				=> $data[15],
	                        'custom3'				=> $data[16],
	                        'custom4'				=> $data[17],
	                        'custom5'				=> $data[18],
	                        'custom6'				=> $data[19],
	                        'custom7'				=> $data[20],
	                        'custom8'				=> $data[21],
	                        'custom9'				=> $data[22],
	                        'custom10'				=> $data[23]
	                    );
	                    $item_number = $data[0];
	                    $invalidated = FALSE;
	                    if($item_number != '')
	                    {
	                    	$item_data['item_number'] = $item_number;
		                    $invalidated = $this->Item->item_number_exists($item_number);
	                    }
					}
					else 
					{
						$invalidated = TRUE;
					}

                    if(!$invalidated && $this->Item->save($item_data)) 
                    {
                        $items_taxes_data = NULL;
                        //tax 1
                        if(is_numeric($data[7]) && $data[6] != '')
                        {
                            $items_taxes_data[] = array('name' => $data[6], 'percent' => $data[7] );
                        }

                        //tax 2
                        if(is_numeric($data[9]) && $data[8] != '')
                        {
                            $items_taxes_data[] = array('name' => $data[8], 'percent' => $data[9] );
                        }

                        // save tax values
                        if(count($items_taxes_data) > 0)
                        {
                            $this->Item_taxes->save($items_taxes_data, $item_data['item_id']);
                        }

                        // quantities & inventory Info
                        $employee_id = $this->Employee->get_logged_in_employee_info()->person_id;
                        $emp_info = $this->Employee->get_info($employee_id);
                        $comment ='Qty CSV Imported';

                        $cols = count($data);

                        // array to store information if location got a quantity
                        $allowed_locations = $this->Stock_location->get_allowed_locations();
                        for ($col = 24; $col < $cols; $col = $col + 2)
                        {
                            $location_id = $data[$col];
                            if(array_key_exists($location_id, $allowed_locations))
                            {
                                $item_quantity_data = array(
                                    'item_id' => $item_data['item_id'],
                                    'location_id' => $location_id,
                                    'quantity' => $data[$col + 1],
                                );
                                $this->Item_quantity->save($item_quantity_data, $item_data['item_id'], $location_id);

                                $excel_data = array(
                                    'trans_items' => $item_data['item_id'],
                                    'trans_user' => $employee_id,
                                    'trans_comment' => $comment,
                                    'trans_location' => $data[$col],
                                    'trans_inventory' => $data[$col + 1]
                                );
								
                                $this->Inventory->insert($excel_data);
                                unset($allowed_locations[$location_id]);
                            }
                        }

                        /*
                         * now iterate through the array and check for which location_id no entry into item_quantities was made yet
                         * those get an entry with quantity as 0.
                         * unfortunately a bit duplicate code from above...
                         */
                        foreach($allowed_locations as $location_id => $location_name)
                        {
                            $item_quantity_data = array(
                                'item_id' => $item_data['item_id'],
                                'location_id' => $location_id,
                                'quantity' => 0,
                            );
                            $this->Item_quantity->save($item_quantity_data, $item_data['item_id'], $data[$col]);

                            $excel_data = array(
								'trans_items' => $item_data['item_id'],
								'trans_user' => $employee_id,
								'trans_comment' => $comment,
								'trans_location' => $location_id,
								'trans_inventory' => 0
							);

                            $this->Inventory->insert($excel_data);
                        }
                    }
                    else //insert or update item failure
                    {
                        $failCodes[] = $i;
                    }

					++$i;
                }

				if(count($failCodes) > 0)
				{
					$message = $this->lang->line('items_excel_import_partially_failed') . ' (' . count($failCodes) . '): ' . implode(', ', $failCodes);
					
					echo json_encode(array('success' => FALSE, 'message' => $message));
				}
				else
				{
					echo json_encode(array('success' => TRUE, 'message' => $this->lang->line('items_excel_import_success')));
				}
			}
			else 
			{
                echo json_encode(array('success' => FALSE, 'message' => $this->lang->line('items_excel_import_nodata_wrongformat')));
			}
        }
	}

	public function prices_all()
	{
		$prices= $this->Item->get_all_prices();

		//var_dump($prices->result_array());
        //die();
		//$prices= $pricex->result_array();
   		//die();
   		$data['prices']=$prices;
		$this->load->view('items/prices', $data);
	}

	public function new_price_list()
	{
		//$prices= $this->Item->get_all_prices();

		//var_dump($prices->result_array());

		/*$item_data=array(
					'name'=>'description',
					'id'=>'description_input',
					'class'=>'form-control input-sm',
					'value'=>$_GET["description"]);*/
		$item_data = array(
			'description' => $_GET["description"]
		);

		/*if($this->db->insert('ospos_prices', $item_data))
			{
				//$item_data['item_id'] = $this->db->insert_id();

				//echo "insert ".$_GET["description"];
			}*/
		$this->db->insert('ospos_prices', $item_data);
		//echo "hola ".$_GET["description"];
        //die();
		//$prices= $pricex->result_array();
   		//die();
   		//$data['prices']=$prices;
		//$this->load->view('items/prices', $data);
		$prices= $this->Item->get_all_prices();
   		$data['prices']=$prices;
		$this->load->view('items/prices', $data);
	}

	public function new_price_list_by_item()
	{
		$item_id = $_GET["item_id"];
		$description = $_GET["description"];
		//Crear nueva lista
		$item_data = array(
			'description' => $description
		);
		$this->db->insert('ospos_prices', $item_data);

		//Buscar id de nueva lista
		$price_id = $this->db->insert_id();

		//Agregar articulo a la nueva lista
		$item_data2 = array(
			'price_id' => $price_id,
			'item_id' => $item_id,
		);
		$this->db->insert('ospos_prices_items', $item_data2);

		//Actualizar datos de articulo
		$item_data3 = array(
			'custom1' => $price_id
		);
		$this->db->where('item_id', $item_id);
		$success2 = $this->db->update('ospos_items', $item_data3);
		
		$prices = $this->Item->get_price_list($price_id);
		$items = $this->Item->get_prices_items($price_id);
		$costo_promedio = $this->Item->get_costo_promedio($price_id);

   		$data['price_id'] = round($price_id,0);
   		$data['description'] = $description;
   		$data['prices']=$prices;
   		$data['items']=$items;
   		$data['costo_promedio']=$costo_promedio;
		$this->load->view('items/price_list', $data);
	}

	public function price_list()
	{
		$price_id = $_GET["price_id"];
		$description = $_GET["description"];

		$prices = $this->Item->get_price_list($price_id);
		$items = $this->Item->get_prices_items($price_id);
		$costo_promedio = $this->Item->get_costo_promedio($price_id);

   		$data['price_id'] = round($price_id,0);
   		$data['description'] = $description;
   		$data['prices']=$prices;
   		$data['items']=$items;
   		$data['costo_promedio']=$costo_promedio;
		$this->load->view('items/price_list', $data);
	}

	public function update_price()
	{
		$price_id = $_GET["price_id"];
		$description = $_GET["description"];
		$quantity_purchased = $_GET["quantity_purchased"];
		$quantity_original = $_GET["quantity_original"];
		$item_unit_price = $_GET["item_unit_price"];
		$pay_percent = $_GET["pay_percent"];

		$costo_promedio = $_GET["costo_promedio"];
		$data['costo_promedio']=$costo_promedio;

		$price_data = array(
			'price_id' => $price_id,
			'quantity_purchased' => $quantity_purchased,
			'item_unit_price' => $item_unit_price,
			'pay_percent' => $pay_percent
		);

		$this->db->where('price_id', $price_id);
		$this->db->where('quantity_purchased', $quantity_original);
		$success = $this->db->update('ospos_price_list', $price_data);

		//Actualiza precio en maestro de artículos
		$unit_price = $this->Item->get_max_price($price_id);
		$item_data = array(
			'unit_price' => $unit_price
		);
		$this->db->where('custom1', $price_id);
		$success2 = $this->db->update('ospos_items', $item_data);
		//////
		
		$prices= $this->Item->get_price_list($price_id);
		$items=$this->Item->get_prices_items($price_id);
   		$data['price_id'] = $price_id;
   		$data['description'] = $description;
   		$data['prices']=$prices;
   		$data['items']=$items;
		$this->load->view('items/price_list', $data);
	}

	public function new_price()
	{
		$price_id = $_GET["price_id"];
		$description = $_GET["description"];
		$quantity_purchased = $_GET["quantity_purchased"];
		$item_unit_price = $_GET["item_unit_price"];

		$costo_promedio = $_GET["costo_promedio"];
		$data['costo_promedio']=$costo_promedio;

		$item_data = array(
			'price_id' => $price_id,
			'quantity_purchased' => $quantity_purchased,
			'item_unit_price' => $item_unit_price
		);

		$this->db->insert('ospos_price_list', $item_data);

		//Actualiza precio en maestro de artículos
		$unit_price = $this->Item->get_max_price($price_id);
		$item_data = array(
			'unit_price' => $unit_price
		);
		$this->db->where('custom1', $price_id);
		$success2 = $this->db->update('ospos_items', $item_data);
		//////

		$prices= $this->Item->get_price_list($price_id);
		$items=$this->Item->get_prices_items($price_id);
   		$data['price_id'] = $price_id;
   		$data['description'] = $description;
   		$data['prices']=$prices;
   		$data['items']=$items;
		$this->load->view('items/price_list', $data);

	}

	public function new_price_box()
	{
		$price_id = $_GET["price_id"];
		$description = $_GET["description"];
		$quantity_purchased = $_GET["quantity_purchased"];
		$item_unit_price = $_GET["item_unit_price"];
		$porcentaje = $_GET["porcentaje"];

		$costo_promedio = $_GET["costo_promedio"];
		$data['costo_promedio']=$costo_promedio;
		
		$division = 0;
		/*if($porcentaje==(-1){
			$division = $item_unit_price/$quantity_purchased;
		}
		if($item_unit_price==(-1)){
			$division = ($costo_promedio+($costo_promedio*$porcentaje/100))/$quantity_purchased;
		}
*/
		$item_data = array(
			'price_id' => $price_id,
			'quantity_purchased' => $quantity_purchased,
			'item_unit_price' => $item_unit_price/$quantity_purchased
		);

		$this->db->insert('ospos_price_list', $item_data);


		//Actualiza precio en maestro de artículos
		$unit_price = $this->Item->get_max_price($price_id);
		$item_data = array(
			'unit_price' => $unit_price
		);
		$this->db->where('custom1', $price_id);
		$success2 = $this->db->update('ospos_items', $item_data);
		//////

		$prices= $this->Item->get_price_list($price_id);
		$items=$this->Item->get_prices_items($price_id);
   		$data['price_id'] = $price_id;
   		$data['description'] = $description;
   		$data['prices']=$prices;
   		$data['items']=$items;
		$this->load->view('items/price_list', $data);

	}

	public function delete_price()
	{
		$price_id = $_GET["price_id"];
		$description = $_GET["description"];
		$quantity_purchased = $_GET["quantity_purchased"];
		$item_unit_price = $_GET["item_unit_price"];

		$costo_promedio = $_GET["costo_promedio"];
		$data['costo_promedio']=$costo_promedio;
		
		$success = $this->db->delete('ospos_price_list', array('price_id' => $price_id,'quantity_purchased' => $quantity_purchased));

		$prices= $this->Item->get_price_list($price_id);
		$items=$this->Item->get_prices_items($price_id);
   		$data['price_id'] = $price_id;
   		$data['description'] = $description;
   		$data['prices']=$prices;
   		$data['items']=$items;
		$this->load->view('items/price_list', $data);
	}

	public function prices_items()
	{
		$price_id = $_GET["price_id"];
		$description = $_GET["description"];
		$costo_promedio = $_GET["costo_promedio"];

		$items= $this->Item->get_all();

   		$data['items']=$items;
   		$data['price_id']=$price_id;
		$data['description']=$description;
		$data['costo_promedio']=$costo_promedio;
		$this->load->view('items/prices_items', $data);
	}

	public function new_prices_items()
	{

		$item_number = $this->input->post('item');
		$item_id = $this->Item->get_id_item($item_number);
		$item_info = $this->Item->get_info_by_id_or_number_custom($item_id);
		$custom2 = $item_info->custom2;
		$name = $item_info->name;
		$price_id = $this->input->post('price_id');
		$description = $this->input->post('description');
		
		$costo_promedio = $this->input->post('costo_promedio');
		//echo $item_number. " id ".$item_id." price ".$price_id;
		//die();

		$success = $this->db->delete('ospos_prices_items', array('item_id' => $item_id));

		$item_data = array(
			'price_id' => $price_id,
			'item_id' => $item_id,
		);

		$this->db->insert('ospos_prices_items', $item_data);


		//Actualiza precio en maestro de artículos
		$unit_price = $this->Item->get_max_price($price_id);


		$item_data = array(
			'custom1' => $price_id,
			'cost_price' => $costo_promedio,
			'unit_price' => $unit_price
		);
		$this->db->where('item_id', $item_id);
		$success2 = $this->db->update('ospos_items', $item_data);

		$prices= $this->Item->get_price_list($price_id);
		$items=$this->Item->get_prices_items($price_id);
   		$data['price_id'] = $price_id;
   		$data['description'] = $description;
   		$data['prices']=$prices;
   		$data['items']=$items;
   		$data['costo_promedio']=$costo_promedio;
		$this->load->view('items/price_list', $data);
	}

	public function delete_prices_items()
	{
		$price_id = $_GET["price_id"];
		$description = $_GET["description"];
		$item_id = $_GET["item_id"];

		$costo_promedio = $_GET["costo_promedio"];
		$data['costo_promedio']=$costo_promedio;

		$success = $this->db->delete('ospos_prices_items', array('item_id' => $item_id));

		$prices= $this->Item->get_price_list($price_id);
		$items=$this->Item->get_prices_items($price_id);
   		$data['price_id'] = $price_id;
   		$data['description'] = $description;
   		$data['prices']=$prices;
   		$data['items']=$items;
   		
		$this->load->view('items/price_list', $data);
	}

	//Para traer la lista de precios a partir de un item
	public function price_list_item()
	{
		$item_id = $_GET["item_id"];
		$price_id = 1;
		$prices= $this->Item->get_price_list($price_id);
		$items=$this->Item->get_prices_items($price_id);
   		$data['price_id'] = $price_id;
   		$data['description'] = $description;
   		$data['prices']=$prices;
   		$data['items']=$items;
   		$data['costo_promedio']=$costo;
		$this->load->view('items/price_list', $data);
	}


	public function update_costo()
	{
		$price_id = $_GET["price_id"];
		$description = $_GET["description"];
		$costo = $_GET["costo"];

		$item_data = array(
			'cost_price' => $costo
		);
		$this->db->where('custom1', $price_id);
		$success2 = $this->db->update('ospos_items', $item_data);

		$prices= $this->Item->get_price_list($price_id);
		$items=$this->Item->get_prices_items($price_id);
   		$data['price_id'] = $price_id;
   		$data['description'] = $description;
   		$data['prices']=$prices;
   		$data['items']=$items;
   		$data['costo_promedio']=$costo;
		$this->load->view('items/price_list', $data);
	}

	public function new_price_percent()
	{
		$price_id = $_GET["price_id"];
		$description = $_GET["description"];
		$quantity_purchased = $_GET["quantity_purchased"];
		$porcentaje = $_GET["porcentaje"];
		$costo_promedio = $_GET["costo_promedio"];
		if ($quantity_purchased == 0){
			$quantity_purchased = 1;
		}
		$precio_sin_ganancia = $costo_promedio * $quantity_purchased;

		$precio_con_ganacia = $precio_sin_ganancia + ($precio_sin_ganancia*$porcentaje/100);
		
		$precio = round($precio_con_ganacia/$quantity_purchased);

		if ($quantity_purchased == 1){
			$quantity_purchased = 0;
		}
		/*echo "$caja_sin_ganancia ".$caja_sin_ganancia."<br>";
		echo "$caja_con_ganacia ".$caja_con_ganacia."<br>";
		echo "$precio ".$precio."<br>";
		die();*/
		$item_data = array(
			'price_id' => $price_id,
			'quantity_purchased' => $quantity_purchased,
			'item_unit_price' => $precio
		);

		$this->db->insert('ospos_price_list', $item_data);

		//Actualiza precio en maestro de artículos
		$unit_price = $this->Item->get_max_price($price_id);
		$item_data = array(
			'unit_price' => $unit_price
		);
		$this->db->where('custom1', $price_id);
		$success2 = $this->db->update('ospos_items', $item_data);
		//////

		$prices= $this->Item->get_price_list($price_id);
		$items=$this->Item->get_prices_items($price_id);
   		$data['price_id'] = $price_id;
   		$data['description'] = $description;
   		$data['prices']=$prices;
   		$data['items']=$items;
   		$data['costo_promedio']=$costo_promedio;
		$this->load->view('items/price_list', $data);

	}

	public function price_list_from_table($item_id = -1)
	{
		

		$price_id = $this->Item->get_price_id($item_id);
		
		if(isset($price_id)){
			$description = $this->Item->get_desc_price($price_id);
			$prices = $this->Item->get_price_list($price_id);
			$items = $this->Item->get_prices_items($price_id);
			$costo_promedio = $this->Item->get_costo_promedio($price_id);

	   		$data['price_id'] = round($price_id,0);
	   		$data['description'] = $description;
	   		$data['prices']=$prices;
	   		$data['items']=$items;
	   		$data['costo_promedio']=$costo_promedio;
			$this->load->view('items/price_list', $data);
		}else
		{
			$data['item_id'] = $item_id;
			$item_info = $this->Item->get_info_by_id_or_number_custom($item_id);
			$data['description'] = $item_info->name;
			$data['item_number'] = $item_info->item_number;
			$this->load->view('items/no_prices', $data);

		}
		
		
	}

	public function item_search()
	{
		$suggestions = array();
		$search = $this->input->get('term') != '' ? $this->input->get('term') : NULL;

		$suggestions = array_merge($suggestions, $this->Item->get_search_suggestions($search, array('search_custom' => FALSE, 'is_deleted' => FALSE), TRUE));
		
		$suggestions = $this->xss_clean($suggestions);

		echo json_encode($suggestions);
	}

	public function price_list_supplier()
	{	
		
		$item_id = $this->input->get('item_id');

		$supplier_id = $this->Item->get_item_supplier($item_id);

		$sales = $this->Item->get_supplier_price_list($supplier_id);
		
		$data = array();
		$data['sales'] = array();
		$data['sales'] = $sales;
		$data['supplier'] = $this->Person->get_name($supplier_id);
		$data['title'] = "LISTA DE PRECIOS";
		$data['subtitle'] = "Proveedor: ".$data['supplier'];
		$this->load->view('items/price_list_supplier', $data);
	}

	public function update_custom2()
	{
		$price_id = $_GET["price_id"];
		$description = $_GET["description"];
		$costo = $_GET["costo"];
		$custom2 = $_GET["custom2"];

		$item_data = array(
			'custom2' => $custom2
		);
		$this->db->where('custom1', $price_id);
		$success2 = $this->db->update('ospos_items', $item_data);

		$prices= $this->Item->get_price_list($price_id);
		$items=$this->Item->get_prices_items($price_id);
   		$data['price_id'] = $price_id;
   		$data['description'] = $description;
   		$data['prices']=$prices;
   		$data['items']=$items;
   		$data['costo_promedio']=$costo;
		$this->load->view('items/price_list', $data);
	}

	public function update_custom4()
	{
		$price_id = $_GET["price_id"];
		$description = $_GET["description"];
		$costo = $_GET["costo"];
		$custom4 = $_GET["custom4"];

		$item_data = array(
			'custom4' => $custom4
		);
		$this->db->where('custom1', $price_id);
		$success2 = $this->db->update('ospos_items', $item_data);

		$prices= $this->Item->get_price_list($price_id);
		$items=$this->Item->get_prices_items($price_id);
   		$data['price_id'] = $price_id;
   		$data['description'] = $description;
   		$data['prices']=$prices;
   		$data['items']=$items;
   		$data['costo_promedio']=$costo;
		$this->load->view('items/price_list', $data);
	}

	public function price_list_category()
	{	
		
		$category = $this->input->get('category');

		$sales = $this->Item->get_category_price_list($category);
		
		$data = array();
		$data['sales'] = array();
		$data['sales'] = $sales;
		$data['category'] = $category;
		$data['title'] = "LISTA DE PRECIOS";
		$data['subtitle'] = "Categoría: ".$data['category'];
		$this->load->view('items/price_list_category', $data);
	}

	public function listar_receiving_stock()
	{	
		
		$fecha_ini = $_GET["fecha_ini"];
		$fecha_fin = $_GET["fecha_fin"];

		$sales = $this->Item->get_receiving_stock($fecha_ini, $fecha_fin);
		$empleado = $this->Employee->get_logged_in_employee_info()->first_name." ".$this->Employee->get_logged_in_employee_info()->last_name;
		$data = array();
		$data['sales'] = array();
		$data['sales'] = $sales;
		$data['fecha_ini'] = $fecha_ini;
		$data['fecha_fin'] = $fecha_fin;
		$data['title'] = "LISTADO DE ENTRADAS/SALIDAS CON STOCK ACTUAL";
		$data['subtitle'] = 'Desde '.$fecha_ini.' hasta '.$fecha_fin;
		
		$this->load->view('items/receiving_stock_list', $data);
	}

	public function listar_vencimientos()
	{	
		
		$fecha_ini = $_GET["fecha_ini"];
		$fecha_fin = $_GET["fecha_fin"];

		$sales = $this->Item->get_vencimientos($fecha_ini, $fecha_fin);
		$empleado = $this->Employee->get_logged_in_employee_info()->first_name." ".$this->Employee->get_logged_in_employee_info()->last_name;
		$data = array();
		$data['sales'] = array();
		$data['sales'] = $sales;
		$data['fecha_ini'] = $fecha_ini;
		$data['fecha_fin'] = $fecha_fin;
		$data['title'] = "LISTADO DE VENCIMIENTOS";
		$data['subtitle'] = 'Desde '.$fecha_ini.' hasta '.$fecha_fin;
		
		$this->load->view('items/vencimientos_list', $data);
	}

	public function pos_buttons()
	{	



			$items = $this->Item->get_pos_list();

	  
	   		$data['items']=$items;
	   		

		
		$this->load->view('items/pos_buttons', $data);
	}


	public function new_pos_items()
	{

		$item_number = $this->input->post('item');
		$item_id = $this->Item->get_id_item($item_number);
		$item_info = $this->Item->get_info_by_id_or_number_custom($item_id);
		$name = $item_info->name;
		$category = $item_info->category;
		$pos_id = $this->Item->get_max_pos_id()+1;

		$item_data = array(
			'pos_id' => $pos_id,
			'item_id' => $item_id,
			'item_name' => $name,
			'button_type' => 'btn-default',
			'button_size' => 'btn-md',
			'item_number' => $item_number,
			'category' => $category

		);

		$this->db->insert('ospos_items_pos', $item_data);


		$items = $this->Item->get_pos_list();

	  
	   	$data['items']=$items;
		
		$this->load->view('items/pos_buttons', $data);
	}

	public function update_pos_items()
	{
		$pos_id = $_GET["pos_id"];
		$button_size = $_GET["button_size"];
		$button_type = $_GET["button_type"];
		
		$item_data = array(
			'button_size' => $button_size,
			'button_type' => $button_type
		);
		$this->db->where('pos_id', $pos_id);
		$success2 = $this->db->update('ospos_items_pos', $item_data);

		$items = $this->Item->get_pos_list();

	  
	   	$data['items']=$items;
		
		$this->load->view('items/pos_buttons', $data);
	}

	public function delete_pos_items()
	{
		$pos_id = $_GET["pos_id"];


		$success = $this->db->delete('ospos_items_pos', array('pos_id' => $pos_id));

		$items = $this->Item->get_pos_list();

	  
	   	$data['items']=$items;
		
		$this->load->view('items/pos_buttons', $data);
	}
	
	/*Fórmulas*/

public function formulas()
	{	

		$items = $this->Item->get_formulas();

	  
	   	$data['items']=$items;
	   		

		$this->load->view('items/formulas', $data);
	}

public function add_formula()
	{	
		
		$this->load->view('items/add_formula', $data);
	}

public function save_formula()
	{	
		$item = $this->input->post('item');
		$item_id = $this->Item->get_id_item($item);
		$description = $this->input->post('description');
		$item_info = $this->Item->get_info_by_id_or_number_custom($item_id);
		$quantity = 1;
		$unit_measurement = 'U';
		if ($item_id == null || $description == null) {
			$data['error'] = "Verifique la descripción y el código ingresado";
			$this->load->view('items/add_formula', $data);
		}else{
			
			$item_data = array(
			'description' => $description,
			'item_id' => $item_id,
			'quantity' => $quantity,
			'unit_measurement' => $unit_measurement
			);
			$this->db->insert('ospos_formulas', $item_data);
			$data['success'] = 'Fórmula creada, agregue la materia prima';
			
			$formula_id = $this->db->insert_id();
			$formula_id = $data['formula_id'];
			
			$items = $this->Item->get_formulas_items($formula_id);
	   		$data['items']=$items;

			$data['description'] = $description;
			$data['item_number'] = $item;
			$data['item_id'] = $item_id;
			$data['name'] = $item_info->name;
			$data['quantity'] = $quantity;
			$data['unit_measurement'] = $unit_measurement;
			$this->load->view('items/edit_formula', $data);
		}
		
		
	}

public function edit_formula()
	{	
		$formula_id = $this->input->get('formula_id');
		$items = $this->Item->get_formulas_items($formula_id);
	   	$data['items']=$items;

		$data['description'] = $this->input->get('description');
		$data['item_number'] = $this->input->get('item_number');
		$data['item_id'] = $this->input->get('item_id');
		$data['name'] = $this->input->get('name');
		$data['quantity'] = $this->input->get('quantity');
		$data['unit_measurement'] = $this->input->get('unit_measurement');
		$data['formula_id'] = $formula_id;
		$this->load->view('items/edit_formula', $data);	
	}

public function delete_formula()
	{	
		$formula_id = $this->input->get('formula_id');

		$success1 = $this->db->delete('ospos_formulas_items', array('formula_id' => $formula_id));

		$success2 = $this->db->delete('ospos_formulas', array('formula_id' => $formula_id));

		$items = $this->Item->get_formulas();
	  
	   	$data['items']=$items;
	   		
		$this->load->view('items/formulas', $data);
	}

public function add_item_formula()
	{	
		$item = $this->input->post('item');
		$quantity_item = $this->input->post('quantity_item');
		$formula_id = $this->input->post('formula_id');
		$item_id_item = $this->Item->get_id_item($item);
		

		$unit_measurement_item = 'U';
		if ($item == null || $quantity_item == null) {
			$data['error'] = "Verifique la cantidad y el código ingresado";
		}else{

			//echo "string1 ".$formula_id." ".$item_id_item." ".$quantity_item." ".$unit_measurement_item;
			
			$item_data = array(
				'item_id' => $item_id_item,
				'quantity' => $quantity_item,
				'unit_measurement' => $unit_measurement_item,
				'formula_id' => $formula_id
				);
			$this->db->insert('ospos_formulas_items', $item_data);
			//die(); 
			$items = $this->Item->get_formulas_items($formula_id);
	   		$data['items']=$items;
	   		
			$data['success'] = 'Materia prima agregada';			
			
			$data['formula_id'] = $formula_id;
			$data['description'] = $this->input->post('description');
			$data['item_number'] = $this->input->post('item_number');
			$data['item_id'] = $this->input->post('item_id');
			$data['name'] = $this->input->post('name');
			$data['quantity'] = $this->input->post('quantity');
			$data['unit_measurement'] = $this->input->post('unit_measurement');
		}
		$this->load->view('items/edit_formula', $data);	
	}
	
public function delete_item_formula()
	{	
		$item_id_item = $this->input->get('item_id_item');
		
		$formula_id = $this->input->get('formula_id');
		
		$success = $this->db->delete('ospos_formulas_items', array('formula_id' => $formula_id,'item_id' => $item_id_item));

		$items = $this->Item->get_formulas_items($formula_id);
	   	$data['items']=$items;
	   		
		//$data['success'] = 'Materia prima agregada';			
			
		$data['formula_id'] = $formula_id;
		$data['description'] = $this->input->get('description');
		$data['item_number'] = $this->input->get('item_number');
		$data['item_id'] = $this->input->get('item_id');
		$data['name'] = $this->input->get('name');
		$data['quantity'] = $this->input->get('quantity');
		$data['unit_measurement'] = $this->input->get('unit_measurement');
		
		$this->load->view('items/edit_formula', $data);	
	}

	
/*Fin Fórmulas*/

	//Inventario ajuste varios

	public function multiple_inventory()
	{	
		$items2 = $this->item_lib->get_items();
		$location_id= $this->item_lib->get_inventory_location();
		$data['location_id']=$location_id;
		$location_name=$this->Item->get_location_name($location_id);
		$data['location_name']=$location_name;
		$usuarios = array();
		$usuarios= $this->Employee->get_users_locations();
		$data['usuarios']=array();
   		$data['usuarios']=$usuarios;
		$data['items'] = array();
		$data['items'] = $items2;
		$data['success'] = $this->item_lib->get_alert();	
		$this->item_lib->remove_alert();	
		$this->load->view('items/multiple_inventory', $data);
	}

	public function set_inventory_location()
	{	
		$location_id = $this->input->get('location_id');
		$this->item_lib->set_inventory_location($location_id);
		$this->multiple_inventory();
	}

	public function add_item()
	{

		$item_number = $this->input->post('item');
		//$location_id = $this->input->post('location_id');
		$item_id = $this->Item->get_id_item($item_number);
		$item_info = $this->Item->get_info_by_id_or_number_custom($item_id);
		$quantity = 1;
		/*if(empty($item_info))
		{
			$item_id = -1;
            return FALSE;			
		}*/
		
		$cost_price = $item_info->cost_price;
		$unit_price = $item_info->unit_price;
		$name = $item_info->name;
		//echo $item_info->name;
		
		//echo "name ".$name;
		$items = $this->item_lib->get_items();
		//var_dump($items);
		//die();
		$insertkey = 0;
		foreach($items as $item)
		{
			$insertkey = $insertkey+1;
		}
		//echo "in ".$insertkey;
		//die();
		$insertkey = $insertkey+1;
		$item = array($insertkey => array(
				'line'=>$insertkey,
				'item_id' => $item_id,
				'item_number' => $item_number,
				'name' => $name,
				'cost_price' => round($cost_price),
				'unit_price' => $unit_price,
				'quantity' => $quantity
			)
		);
		//var_dump($label);
		//add to existing array
		$items += $item;
		

		$this->item_lib->set_items($items);

		$this->multiple_inventory();
	}

	public function edit_item()
	{
		/*$line, $serialnumber, $quantity, $discount, $price*/
		$line = $this->input->get('line');
		$cost_price = $this->input->get('cost_price');
		$quantity = $this->input->get('quantity');
		$item_id = $this->input->get('item_id');

		$items = $this->item_lib->get_items();

		//var_dump($items);
		//die();
		if(isset($items[$line]))	
		{

			$line = &$items[$line];
			
			$line['cost_price'] = $cost_price;
			$line['quantity'] = $quantity;

			$this->item_lib->set_items($items);
		}

		$this->multiple_inventory();
	}

	public function delete_item()
	{
		$line = $this->input->get('line');
		$items = $this->item_lib->get_items();
		unset($items[$line]);
		$this->item_lib->set_items($items);
		$this->multiple_inventory();
	}
	
	public function save_multiple_inventory()
	{	
		$items = $this->item_lib->get_items();
		$location_id= $this->item_lib->get_inventory_location();
		$employee_id = $this->Employee->get_logged_in_employee_info()->person_id;
		$this->db->trans_start();
		foreach($items as $item)
		{
			//ACTUALIZA COSTO
			$item_data = array(
			'cost_price' => $item['cost_price']
			);
			$this->db->where('item_id', $item['item_id']);
			$success1 = $this->db->update('ospos_items', $item_data);

			//ACTUALIZA STOCK
			$stock = $this->Item->get_stock_item_loc($item['item_id'],$location_id);
			$item_data = array(
			'quantity' => $stock+$item['quantity']
			);
			$this->db->where('item_id', $item['item_id']);
			$this->db->where('location_id', $location_id);
			$success1 = $this->db->update('ospos_item_quantities', $item_data);

			//ACTUALIZA AUDITORIA

			$inv_data = array(
				'trans_date'		=> date('Y-m-d H:i:s'),
				'trans_items'		=> $item['item_id'],
				'trans_user'		=> $employee_id,
				'trans_location'	=> $location_id,
				'trans_comment'		=> 'E/S INVENTARIO',
				'trans_inventory'	=> $item['quantity']
			);
			$this->Inventory->insert($inv_data);

		}
		$this->db->trans_complete();
		if($this->db->trans_status() === FALSE)
		{
			$this->item_lib->set_alert('NO GUARDADO. Verifique datos');
			$this->multiple_inventory();
			
		}else{
			$this->item_lib->empty_items();
			$this->item_lib->set_alert('Datos Guardados');	
		}
		
		
		
		$this->multiple_inventory();
	
	}


	/*PACK ARTICULOS*/

	
	public function pack_items($item_id)
	{	
		
		$items= $this->Item->get_pack_items($item_id);
		//var_dump($items);
		//die();
		$data['item_id'] = $item_id;
		$item_info = $this->Item->get_info_by_id_or_number_custom($item_id);
		$data['item_info'] = array();
		$data['item_info'] = $item_info;
		$data['items'] = array();
		$data['items'] = $items;		
		$this->load->view('items/pack_items', $data);
	}

	public function add_item_pack()
	{
		$item_padre = $this->input->post('item_padre');
		$item_number = $this->input->post('item');
		//$location_id = $this->input->post('location_id');
		$item_id = $this->Item->get_id_item($item_number);
		$item_info = $this->Item->get_info_by_id_or_number_custom($item_id);
		$quantity = 1;
		
		$cost_price = $item_info->cost_price;
		$unit_price = $item_info->unit_price;

		$pack_data = array(
				'item_id'		=> $item_padre,
				'item_id_item'	=> $item_id,
				'quantity'		=> $quantity,
				'cost_price'	=> $cost_price,
				'unit_price'	=> $unit_price
		);
		$this->db->insert('ospos_item_pack_items', $pack_data);
		$this->pack_items($item_padre);
	}

	public function delete_item_pack()
	{
		$item_id = $this->input->get('item_padre');
		$quantity = $this->input->get('quantity');
		$item_id_item = $this->input->get('item_id');
		$success = $this->db->delete('ospos_item_pack_items', array('item_id' => $item_id,'item_id_item' => $item_id_item,'quantity' => $quantity));
		$this->pack_items($item_id);
	}

	public function edit_item_pack()
	{
		$item_id = $this->input->get('item_padre');
		$quantity = $this->input->get('quantity');
		$quantity_original = $this->input->get('quantity_original');
		$cost_price = $this->input->get('cost_price');
		$unit_price = $this->input->get('unit_price');
		$item_id_item = $this->input->get('item_id');
		$success = $this->db->delete('ospos_item_pack_items', array('item_id' => $item_id,'item_id_item' => $item_id_item,'quantity' => $quantity));

		$price_data = array(
			'quantity' => $quantity,
			'unit_price' => $unit_price,
			'cost_price' => $cost_price
		);

		$this->db->where('item_id', $item_id);
		$this->db->where('item_id_item', $item_id_item);
		$this->db->where('quantity', $quantity_original);
		$success = $this->db->update('ospos_item_pack_items', $price_data);
		$this->pack_items($item_id);
	}

	public function inventory_list()
	{
		
		
		$fecha_fin = $_GET["fecha_fin"];
		$location_id = $_GET["location_id"];
		$destino = $_GET["destino"];

		if (strlen($fecha_fin)==0) {
			$hoy = date('Y-m-d');
			//echo "fecha fin cero ";
			$fecha_fin = $hoy;
			//echo $fecha_fin;
		}
		$inventory= $this->Item->get_inventory_stock_date($location_id,'2010-01-01',$fecha_fin);
		$fecha_ini = '';
		//echo $fecha_fin;
		$location_name= $this->Item->get_location_name($location_id);
		$data['location_name']=$location_name;


		if ($destino!=null) {
			if ($destino!='pantalla') {
				$destino='excel';
			}
		}else{
			$destino='pantalla';
		}
		$usuarios = array();
		$usuarios= $this->Employee->get_users_locations();
		$data['usuarios']=array();
   		$data['usuarios']=$usuarios;
   		$data['inventory']=array();
   		$data['inventory']=$inventory;
   		$data['destino']=$destino;
   		$data['location_id']=$location_id;
   		$data['fecha_fin']=$fecha_fin;
		$this->load->view('items/inventory_list', $data);
	}
}
?>