<?php
class Receiving extends CI_Model
{
	public function get_info($receiving_id)
	{	
		$this->db->from('receivings');
		$this->db->join('people', 'people.person_id = receivings.supplier_id', 'LEFT');
		$this->db->join('suppliers', 'suppliers.person_id = receivings.supplier_id', 'LEFT');
		$this->db->where('receiving_id', $receiving_id);

		return $this->db->get();
	}

	public function get_receiving_by_reference($reference)
	{
		$this->db->from('receivings');
		$this->db->where('reference', $reference);

		return $this->db->get();
	}

	public function is_valid_receipt($receipt_receiving_id)
	{
		if(!empty($receipt_receiving_id))
		{
			//RECV #
			$pieces = explode(' ', $receipt_receiving_id);

			if(count($pieces) == 2 && preg_match('/(RECV|KIT)/', $pieces[0]))
			{
				return $this->exists($pieces[1]);
			}
			else 
			{
				return $this->get_receiving_by_reference($receipt_receiving_id)->num_rows() > 0;
			}
		}

		return FALSE;
	}

	public function exists($receiving_id)
	{
		$this->db->from('receivings');
		$this->db->where('receiving_id', $receiving_id);

		return ($this->db->get()->num_rows() == 1);
	}
	
	public function update($receiving_data, $receiving_id)
	{
		$this->db->where('receiving_id', $receiving_id);

		return $this->db->update('receivings', $receiving_data);
	}

	public function save($items, $supplier_id, $employee_id, $comment, $reference, $payment_type, $receiving_id = FALSE)
	{
		if(count($items) == 0)
		{
			return -1;
		}
		$person_id = $this->Employee->get_logged_in_employee_info()->person_id;
		$habilitacion_caja = $this->Sale->get_habilitacion_caja($person_id);
		$mode = $this->receiving_lib->get_mode();

		$receivings_data = array(
			'receiving_time' => date('Y-m-d H:i:s'),
			'supplier_id' => $this->Supplier->exists($supplier_id) ? $supplier_id : NULL,
			'employee_id' => $employee_id,
			'payment_type' => $payment_type,
			'comment' => $comment,
			'reference' => $reference,
			'caja_id' => $habilitacion_caja,
			'mode' => $mode

		);

		//Run these queries as a transaction, we want to make sure we do all or nothing
		$this->db->trans_start();

		$this->db->insert('receivings', $receivings_data);
		$receiving_id = $this->db->insert_id();

		foreach($items as $line=>$item)
		{
			$cur_item_info = $this->Item->get_info($item['item_id']);
			$codigo = $this->Item->get_item_number($item['item_id']);
			$categoria = $this->Item->get_category($codigo);
			$item_idx = $item['item_id'];
			//echo "string ".$item_idx;

			$costox = $item['price'];
			$costo = 0;
			if ($categoria == 'GASTOS') {
				$costo = 0;
			}else
			{
				$costo = $cur_item_info->cost_price;
			}
			$receivings_items_data = array(
				'receiving_id' => $receiving_id,
				'item_id' => $item['item_id'],
				'line' => $item['line'],
				'description' => $item['description'],
				'serialnumber' => $item['serialnumber'],
				'quantity_purchased' => $item['quantity'],
				'receiving_quantity' => $item['receiving_quantity'],
				'discount_percent' => $item['discount'],
				'item_cost_price' => $costo,
				'item_unit_price' => $item['price'],
				'item_location' => $item['item_location'],
				'expiry_date' => $item['expiry_date']
			);

			$this->db->insert('receivings_items', $receivings_items_data);

			$items_received = $item['receiving_quantity'] != 0 ? $item['quantity'] * $item['receiving_quantity'] : $item['quantity'];

			// update cost price, if changed AND is set in config as wanted
			if($cur_item_info->cost_price != $item['price'] && $this->config->item('receiving_calculate_average_price') != FALSE)
			{
				$this->Item->change_cost_price($item['item_id'], $items_received, $item['price'], $cur_item_info->cost_price);
			}

			//Update stock quantity
			$item_quantity = $this->Item_quantity->get_item_quantity($item['item_id'], $item['item_location']);
            $this->Item_quantity->save(array('quantity' => $item_quantity->quantity + $items_received, 'item_id' => $item['item_id'],
                                              'location_id' => $item['item_location']), $item['item_id'], $item['item_location']);

			$recv_remarks = 'RECV ' . $receiving_id;
			$inv_data = array(
				'trans_date' => date('Y-m-d H:i:s'),
				'trans_items' => $item['item_id'],
				'trans_user' => $employee_id,
				'trans_location' => $item['item_location'],
				'trans_comment' => $recv_remarks,
				'trans_inventory' => $items_received
			);

			$this->Inventory->insert($inv_data);

			$supplier = $this->Supplier->get_info($supplier_id);

			//Actualizar costo
			//Verificar si es compra para modificar el costo
			/*if ($item['quantity']>0) {
				$item_datax = array(
				'cost_price' => $costox
				);
				$this->db->where('item_id', $item_idx);
				$success2 = $this->db->update('ospos_items', $item_datax);
				//Fin Actualiza costo
			}*/
			//Fin Actualiza costo
		}

		$this->db->trans_complete();
		
		if($this->db->trans_status() === FALSE)
		{
			return -1;
		}

		return $receiving_id;
	}
	
	public function delete_list($receiving_ids, $employee_id, $update_inventory = TRUE)
	{
		$success = TRUE;

		// start a transaction to assure data integrity
		$this->db->trans_start();

		foreach($receiving_ids as $receiving_id)
		{
			$success &= $this->delete($receiving_id, $employee_id, $update_inventory);
		}

		// execute transaction
		$this->db->trans_complete();

		$success &= $this->db->trans_status();

		return $success;
	}
	
	public function delete($receiving_id, $employee_id, $update_inventory = TRUE)
	{
		// start a transaction to assure data integrity
		$this->db->trans_start();

		if($update_inventory)
		{
			// defect, not all item deletions will be undone??
			// get array with all the items involved in the sale to update the inventory tracking
			$items = $this->get_receiving_items($receiving_id)->result_array();
			foreach($items as $item)
			{
				// create query to update inventory tracking
				$inv_data = array(
					'trans_date' => date('Y-m-d H:i:s'),
					'trans_items' => $item['item_id'],
					'trans_user' => $employee_id,
					'trans_comment' => 'Deleting receiving ' . $receiving_id,
					'trans_location' => $item['item_location'],
					'trans_inventory' => $item['quantity_purchased'] * -1
				);
				// update inventory
				$this->Inventory->insert($inv_data);

				// update quantities
				$this->Item_quantity->change_quantity($item['item_id'], $item['item_location'], $item['quantity_purchased'] * -1);
			}
		}

		// delete all items
		$this->db->delete('receivings_items', array('receiving_id' => $receiving_id));
		// delete sale itself
		$this->db->delete('receivings', array('receiving_id' => $receiving_id));

		// execute transaction
		$this->db->trans_complete();
	
		return $this->db->trans_status();
	}

	public function get_receiving_items($receiving_id)
	{
		$this->db->from('receivings_items');
		$this->db->where('receiving_id', $receiving_id);

		return $this->db->get();
	}
	
	public function get_supplier($receiving_id)
	{
		$this->db->from('receivings');
		$this->db->where('receiving_id', $receiving_id);

		return $this->Supplier->get_info($this->db->get()->row()->supplier_id);
	}

	public function get_payment_options()
	{
		return array(
			$this->lang->line('sales_cash') => $this->lang->line('sales_cash'),
			$this->lang->line('sales_check') => $this->lang->line('sales_check'),
			$this->lang->line('sales_debit') => $this->lang->line('sales_debit'),
			$this->lang->line('sales_credit') => $this->lang->line('sales_credit'),
			'Transferencia' => 'Transferencia'
		);
	}

	/*
	We create a temp table that allows us to do easy report/receiving queries
	*/
	public function create_temp_table(array $inputs)
	{
		if(empty($inputs['receiving_id']))
		{
			$where = 'WHERE DATE(receiving_time) BETWEEN ' . $this->db->escape($inputs['start_date']) . ' AND ' . $this->db->escape($inputs['end_date']);
		}
		else
		{
			$where = 'WHERE receivings_items.receiving_id = ' . $this->db->escape($inputs['receiving_id']);
		}
		
		$this->db->query('CREATE TEMPORARY TABLE IF NOT EXISTS ' . $this->db->dbprefix('receivings_items_temp') . 
			' (INDEX(receiving_date), INDEX(receiving_id))
			(
				SELECT 
					DATE(receiving_time) AS receiving_date,
					receiving_time,
					receivings_items.receiving_id,
					comment,
					item_location,
					reference,
					payment_type,
					employee_id, 
					items.item_id,
					receivings.supplier_id,
					concat(suppliers.agency_name,"AGENCIA") AS nombre_compania,
					quantity_purchased,
					receivings_items.receiving_quantity,
					item_cost_price,
					item_unit_price,
					discount_percent,
					receivings_items.line,
					serialnumber,
					receivings_items.description,
					(item_unit_price * quantity_purchased - item_unit_price * quantity_purchased * discount_percent / 100) AS subtotal,
					(item_unit_price * quantity_purchased - item_unit_price * quantity_purchased * discount_percent / 100) AS total,
					(item_unit_price * quantity_purchased - item_unit_price * quantity_purchased * discount_percent / 100) - (item_cost_price * quantity_purchased) AS profit,
					(item_cost_price * quantity_purchased) AS cost
				FROM ' . $this->db->dbprefix('receivings_items') . ' AS receivings_items
				INNER JOIN ' . $this->db->dbprefix('receivings') . ' AS receivings
					ON receivings_items.receiving_id = receivings.receiving_id
				INNER JOIN ' . $this->db->dbprefix('items') . ' AS items
					ON receivings_items.item_id = items.item_id
				LEFT JOIN ' . $this->db->dbprefix('suppliers') . ' AS suppliers
					ON receivings.supplier_id = suppliers.person_id
				' . "
				$where
				" . '
				GROUP BY receivings_items.receiving_id, items.item_id, receivings_items.line
			)'
		);
	}

	//Reportes para contabilidad
	public function compras_contable($fecha_ini,$fecha_fin)
	{

		$sql="SELECT date(s.receiving_time) fecha,s.reference factura,'' timbrado,p.address_2 ruc,concat(p.first_name,' ',p.last_name) persona,
			(select sum(si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100))) 
			from ospos_receivings_items si,ospos_items_taxes i
			where si.receiving_id=s.receiving_id
			and si.item_id=i.item_id
			and i.percent=10) gravadas_10,
			(select sum(si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100))) 
			from ospos_receivings_items si,ospos_items_taxes i
			where si.receiving_id=s.receiving_id
			and si.item_id=i.item_id
			and i.percent=5) gravadas_05,
			(select sum(si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100))) 
			from ospos_receivings_items si,ospos_items_taxes i
			where si.receiving_id=s.receiving_id
			and si.item_id=i.item_id
			and i.percent=0) exentas,
			'GS' moneda, s.receiving_id sale_id
			from ospos_receivings s,ospos_people p
			where s.supplier_id=p.person_id
			and date(s.receiving_time) BETWEEN ? AND ?
			and s.mode='receive'
			order BY 1,2
			";		
		//echo "in 1 ";
		$query=$this->db->query($sql,array($fecha_ini,$fecha_fin));
		//echo "in 2 ";
		$r=$query->result();
		//echo "in 3 ";
		return $r;
	}

	public function get_receiving_total($habilitacion_caja)
	{	
		$query = $this->db->query("select sum(i.quantity_purchased*(i.item_unit_price-(i.item_unit_price*i.discount_percent/100))) sale_total
			from ospos_receivings_items i,ospos_receivings s
			where i.receiving_id = s.receiving_id
			and s.payment_type = 'Efectivo'
			and s.mode in ('receive','return')
			and s.caja_id = '".$habilitacion_caja."' limit 1");
		$return = 0;
		foreach ($query->result_array() as $row) {
			$return = $row['sale_total'];
		}
		
		
		//echo $return;
		//die();
		return $return;
	}

}
?>
