<?php
class Sale extends CI_Model
{
	public function get_info($sale_id)
	{
		// NOTE: temporary tables are created to speed up searches due to the fact that are ortogonal to the main query
		// create a temporary table to contain all the payments per sale item
		$this->db->query('CREATE TEMPORARY TABLE IF NOT EXISTS ' . $this->db->dbprefix('sales_payments_temp') . 
			'(
				SELECT payments.sale_id AS sale_id, 
					IFNULL(SUM(payments.payment_amount), 0) AS sale_payment_amount,
					GROUP_CONCAT(CONCAT(payments.payment_type, " ", payments.payment_amount) SEPARATOR ", ") AS payment_type
				FROM ' . $this->db->dbprefix('sales_payments') . ' AS payments
				INNER JOIN ' . $this->db->dbprefix('sales') . ' AS sales
					ON sales.sale_id = payments.sale_id
				WHERE sales.sale_id = ' . $this->db->escape($sale_id) . '
				GROUP BY sale_id
			)'
		);

		// create a temporary table to contain all the sum of taxes per sale item
		$this->db->query('CREATE TEMPORARY TABLE IF NOT EXISTS ' . $this->db->dbprefix('sales_items_taxes_temp') . 
			'(
				SELECT sales_items_taxes.sale_id AS sale_id,
					sales_items_taxes.item_id AS item_id,
					SUM(sales_items_taxes.percent) AS percent
				FROM ' . $this->db->dbprefix('sales_items_taxes') . ' AS sales_items_taxes
				INNER JOIN ' . $this->db->dbprefix('sales') . ' AS sales
					ON sales.sale_id = sales_items_taxes.sale_id
				INNER JOIN ' . $this->db->dbprefix('sales_items') . ' AS sales_items
					ON sales_items.sale_id = sales_items_taxes.sale_id AND sales_items.line = sales_items_taxes.line
				WHERE sales.sale_id = ' . $this->db->escape($sale_id) . '
				GROUP BY sales_items_taxes.sale_id, sales_items_taxes.item_id
			)'
		);

		if($this->config->item('tax_included'))
		{
			$sale_total = 'SUM(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100))';
			$sale_subtotal = 'SUM(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100) * (100 / (100 + sales_items_taxes.percent)))';
			$sale_tax = 'SUM(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100) * (1 - 100 / (100 + sales_items_taxes.percent)))';
		}
		else
		{
			$sale_total = 'SUM(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100) * (1 + (sales_items_taxes.percent / 100)))';
			$sale_subtotal = 'SUM(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100))';
			$sale_tax = 'SUM(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100) * (sales_items_taxes.percent / 100))';
		}

		$decimals = totals_decimals();

		$this->db->select('
				sales.sale_id AS sale_id,
				DATE(sales.sale_time) AS sale_date,
				sales.sale_time AS sale_time,
				sales.comment AS comment,
				sales.invoice_number AS invoice_number,
				sales.employee_id AS employee_id,
				sales.customer_id AS customer_id,
				CONCAT(customer_p.first_name, " ", customer_p.last_name) AS customer_name,
				customer_p.first_name AS first_name,
				customer_p.last_name AS last_name,
				customer_p.email AS email,
				customer_p.comments AS comments,
				' . "
				IFNULL(ROUND($sale_total, $decimals), ROUND($sale_subtotal, $decimals)) AS amount_due,
				payments.sale_payment_amount AS amount_tendered,
				(payments.sale_payment_amount - IFNULL(ROUND($sale_total, $decimals), ROUND($sale_subtotal, $decimals))) AS change_due,
				" . '
				payments.payment_type AS payment_type
		');

		$this->db->from('sales_items AS sales_items');
		$this->db->join('sales AS sales', 'sales_items.sale_id = sales.sale_id', 'inner');
		$this->db->join('people AS customer_p', 'sales.customer_id = customer_p.person_id', 'left');
		$this->db->join('customers AS customer', 'sales.customer_id = customer.person_id', 'left');
		$this->db->join('sales_payments_temp AS payments', 'sales.sale_id = payments.sale_id', 'left outer');
		$this->db->join('sales_items_taxes_temp AS sales_items_taxes', 'sales_items.sale_id = sales_items_taxes.sale_id AND sales_items.item_id = sales_items_taxes.item_id', 'left outer');

		$this->db->where('sales.sale_id', $sale_id);

		$this->db->group_by('sales.sale_id');
		$this->db->order_by('sales.sale_time', 'asc');

		return $this->db->get();
	}

	/*
	 Get number of rows for the takings (sales/manage) view
	*/
	public function get_found_rows($search, $filters)
	{
		return $this->search($search, $filters)->num_rows();
	}

	/*
	 Get the sales data for the takings (sales/manage) view
	*/
	public function search($search, $filters, $rows = 0, $limit_from = 0, $sort = 'sale_date', $order = 'desc')
	{
		// NOTE: temporary tables are created to speed up searches due to the fact that are ortogonal to the main query
		// create a temporary table to contain all the payments per sale item
		$this->db->query('CREATE TEMPORARY TABLE IF NOT EXISTS ' . $this->db->dbprefix('sales_payments_temp') . 
			' (PRIMARY KEY(sale_id), INDEX(sale_id))
			(
				SELECT payments.sale_id AS sale_id, 
					IFNULL(SUM(payments.payment_amount), 0) AS sale_payment_amount,
					GROUP_CONCAT(CONCAT(payments.payment_type, " ", payments.payment_amount) SEPARATOR ", ") AS payment_type
				FROM ' . $this->db->dbprefix('sales_payments') . ' AS payments
				INNER JOIN ' . $this->db->dbprefix('sales') . ' AS sales
					ON sales.sale_id = payments.sale_id
				WHERE DATE(sales.sale_time) BETWEEN ' . $this->db->escape($filters['start_date']) . ' AND ' . $this->db->escape($filters['end_date']) . '
				GROUP BY sale_id
			)'
		);

		// create a temporary table to contain all the sum of taxes per sale item
		$this->db->query('CREATE TEMPORARY TABLE IF NOT EXISTS ' . $this->db->dbprefix('sales_items_taxes_temp') . 
			' (INDEX(sale_id), INDEX(item_id))
			(
				SELECT sales_items_taxes.sale_id AS sale_id,
					sales_items_taxes.item_id AS item_id,
					SUM(sales_items_taxes.percent) AS percent
				FROM ' . $this->db->dbprefix('sales_items_taxes') . ' AS sales_items_taxes
				INNER JOIN ' . $this->db->dbprefix('sales') . ' AS sales
					ON sales.sale_id = sales_items_taxes.sale_id
				INNER JOIN ' . $this->db->dbprefix('sales_items') . ' AS sales_items
					ON sales_items.sale_id = sales_items_taxes.sale_id AND sales_items.line = sales_items_taxes.line
				WHERE DATE(sales.sale_time) BETWEEN ' . $this->db->escape($filters['start_date']) . ' AND ' . $this->db->escape($filters['end_date']) . '
				GROUP BY sales_items_taxes.sale_id, sales_items_taxes.item_id
			)'
		);

		if($this->config->item('tax_included'))
		{
			$sale_total = 'SUM(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100))';
			$sale_subtotal = 'SUM(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100) * (100 / (100 + sales_items_taxes.percent)))';
			$sale_tax = 'SUM(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100) * (1 - 100 / (100 + sales_items_taxes.percent)))';
		}
		else
		{
			$sale_total = 'SUM(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100) * (1 + (sales_items_taxes.percent / 100)))';
			$sale_subtotal = 'SUM(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100))';
			$sale_tax = 'SUM(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100) * (sales_items_taxes.percent / 100))';
		}

		$sale_cost = 'SUM(sales_items.item_cost_price * sales_items.quantity_purchased)';

		$decimals = totals_decimals();

		$this->db->select('
				sales.sale_id AS sale_id,
				DATE(sales.sale_time) AS sale_date,
				sales.sale_time AS sale_time,
				sales.ticket AS ticket,
				sales.invoice_number AS invoice_number,
				SUM(sales_items.quantity_purchased) AS items_purchased,
				CONCAT(customer_p.first_name, " ", customer_p.last_name) AS customer_name,
				customer.company_name AS company_name,
				' . "
				ROUND($sale_subtotal, $decimals) AS subtotal,
				IFNULL(ROUND($sale_tax, $decimals), 0) AS tax,
				IFNULL(ROUND($sale_total, $decimals), ROUND($sale_subtotal, $decimals)) AS total,
				ROUND($sale_cost, $decimals) AS cost,
				ROUND($sale_total - $sale_cost, $decimals) AS profit,
				IFNULL(ROUND($sale_total, $decimals), ROUND($sale_subtotal, $decimals)) AS amount_due,
				payments.sale_payment_amount AS amount_tendered,
				(payments.sale_payment_amount - IFNULL(ROUND($sale_total, $decimals), ROUND($sale_subtotal, $decimals))) AS change_due,
				" . '
				payments.payment_type AS payment_type,
				sales.estado as estado,
				sales.comment2 as comment2,
				sales.comment as comment
		');

		$this->db->from('sales_items AS sales_items');
		$this->db->join('sales AS sales', 'sales_items.sale_id = sales.sale_id', 'inner');
		$this->db->join('people AS customer_p', 'sales.customer_id = customer_p.person_id', 'left');
		$this->db->join('customers AS customer', 'sales.customer_id = customer.person_id', 'left');
		$this->db->join('sales_payments_temp AS payments', 'sales.sale_id = payments.sale_id', 'left outer');
		$this->db->join('sales_items_taxes_temp AS sales_items_taxes', 'sales_items.sale_id = sales_items_taxes.sale_id AND sales_items.item_id = sales_items_taxes.item_id', 'left outer');

		$this->db->where('DATE(sales.sale_time) BETWEEN ' . $this->db->escape($filters['start_date']) . ' AND ' . $this->db->escape($filters['end_date']));

		if(!empty($search))
		{
			if($filters['is_valid_receipt'] != FALSE)
			{
				$pieces = explode(' ', $search);
				$this->db->where('sales.sale_id', $pieces[1]);
			}
			else
			{			
				$this->db->group_start();
					// customer last name
					$this->db->like('customer_p.last_name', $search);
					// customer first name
					$this->db->or_like('customer_p.first_name', $search);
					// customer first and last name
					$this->db->or_like('CONCAT(customer_p.first_name, " ", customer_p.last_name)', $search);
					// customer company name
					$this->db->or_like('customer.company_name', $search);
				$this->db->group_end();
			}
		}

		if($filters['location_id'] != 'all')
		{
			$this->db->where('sales_items.item_location', $filters['location_id']);
		}

		if($filters['sale_type'] == 'sales')
        {
            $this->db->where('sales_items.quantity_purchased > 0');
        }
        elseif($filters['sale_type'] == 'returns')
        {
            $this->db->where('sales_items.quantity_purchased < 0');
        }

		if($filters['only_invoices'] != FALSE)
		{
			$this->db->where('sales.invoice_number IS NOT NULL');
		}

		if($filters['only_cash'] != FALSE)
		{
			$this->db->group_start();
				$this->db->like('payments.payment_type', $this->lang->line('sales_cash'), 'after');
				$this->db->or_where('payments.payment_type IS NULL');
			$this->db->group_end();
		}

		$this->db->group_by('sales.sale_id');
		$this->db->order_by($sort, $order);

		if($rows > 0)
		{
			$this->db->limit($rows, $limit_from);
		}

		return $this->db->get();
	}

	/*
	 Get the payment summary for the takings (sales/manage) view
	*/
	public function get_payments_summary($search, $filters)
	{
		// get payment summary
		$this->db->select('payment_type, count(*) AS count, SUM(payment_amount) AS payment_amount');
		$this->db->from('sales');
		$this->db->join('sales_payments', 'sales_payments.sale_id = sales.sale_id');
		$this->db->join('people AS customer_p', 'sales.customer_id = customer_p.person_id', 'left');
		$this->db->join('customers AS customer', 'sales.customer_id = customer.person_id', 'left');

		$this->db->where('DATE(sale_time) BETWEEN ' . $this->db->escape($filters['start_date']) . ' AND ' . $this->db->escape($filters['end_date']));

		if(!empty($search))
		{
			if($filters['is_valid_receipt'] != FALSE)
			{
				$pieces = explode(' ',$search);
				$this->db->where('sales.sale_id', $pieces[1]);
			}
			else
			{
				$this->db->group_start();
					// customer last name
					$this->db->like('customer_p.last_name', $search);
					// customer first name
					$this->db->or_like('customer_p.first_name', $search);
					// customer first and last name
					$this->db->or_like('CONCAT(customer_p.first_name, " ", customer_p.last_name)', $search);
					// customer company name
					$this->db->or_like('customer.company_name', $search);
				$this->db->group_end();
			}
		}

		if($filters['sale_type'] == 'sales')
		{
			$this->db->where('payment_amount > 0');
		}
		elseif($filters['sale_type'] == 'returns')
		{
			$this->db->where('payment_amount < 0');
		}

		if($filters['only_invoices'] != FALSE)
		{
			$this->db->where('invoice_number IS NOT NULL');
		}
		
		if($filters['only_cash'] != FALSE)
		{
			$this->db->like('payment_type', $this->lang->line('sales_cash'), 'after');
		}

		$this->db->group_by('payment_type');

		$payments = $this->db->get()->result_array();

		// consider Gift Card as only one type of payment and do not show "Gift Card: 1, Gift Card: 2, etc." in the total
		$gift_card_count = 0;
		$gift_card_amount = 0;
		foreach($payments as $key=>$payment)
		{
			if( strstr($payment['payment_type'], $this->lang->line('sales_giftcard')) != FALSE )
			{
				$gift_card_count  += $payment['count'];
				$gift_card_amount += $payment['payment_amount'];

				// remove the "Gift Card: 1", "Gift Card: 2", etc. payment string
				unset($payments[$key]);
			}
		}

		if($gift_card_count > 0)
		{
			$payments[] = array('payment_type' => $this->lang->line('sales_giftcard'), 'count' => $gift_card_count, 'payment_amount' => $gift_card_amount);
		}

		return $payments;
	}

	/*
	Gets total of rows
	*/
	public function get_total_rows()
	{
		$this->db->from('sales');

		return $this->db->count_all_results();
	}

	public function get_search_suggestions($search, $limit = 25)
	{
		$suggestions = array();

		if(!$this->is_valid_receipt($search))
		{
			$this->db->distinct();
			$this->db->select('first_name, last_name');
			$this->db->from('sales');
			$this->db->join('people', 'people.person_id = sales.customer_id');
			$this->db->like('last_name', $search);
			$this->db->or_like('first_name', $search);
			$this->db->or_like('CONCAT(first_name, " ", last_name)', $search);
			$this->db->or_like('company_name', $search);
			$this->db->order_by('last_name', 'asc');

			foreach($this->db->get()->result_array() as $result)
			{
				$suggestions[] = array('label' => $result['first_name'] . ' ' . $result['last_name']);
			}
		}
		else
		{
			$suggestions[] = array('label' => $search);
		}

		return $suggestions;
	}

	/*
	Gets total of invoice rows
	*/
	public function get_invoice_count()
	{
		$this->db->from('sales');
		$this->db->where('invoice_number IS NOT NULL');

		return $this->db->count_all_results();
	}

	public function get_sale_by_invoice_number($invoice_number)
	{
		$this->db->from('sales');
		$this->db->where('invoice_number', $invoice_number);

		return $this->db->get();
	}

	public function get_invoice_number_for_year($year = '', $start_from = 0) 
	{
		$year = $year == '' ? date('Y') : $year;
		$this->db->select('COUNT( 1 ) AS invoice_number_year');
		$this->db->from('sales');
		$this->db->where('DATE_FORMAT(sale_time, "%Y" ) = ', $year);
		$this->db->where('invoice_number IS NOT NULL');
		$result = $this->db->get()->row_array();

		return ($start_from + $result['invoice_number_year']);
	}
	
	public function is_valid_receipt(&$receipt_sale_id)
	{
		if(!empty($receipt_sale_id))
		{
			//POS #
			$pieces = explode(' ', $receipt_sale_id);

			if(count($pieces) == 2 && preg_match('/(POS)/', $pieces[0]))
			{
				return $this->exists($pieces[1]);
			}
			elseif($this->config->item('invoice_enable') == TRUE)
			{
				$sale_info = $this->get_sale_by_invoice_number($receipt_sale_id);
				if($sale_info->num_rows() > 0)
				{
					$receipt_sale_id = 'POS ' . $sale_info->row()->sale_id;

					return TRUE;
				}
			}
		}

		return FALSE;
	}

	public function exists($sale_id)
	{
		$this->db->from('sales');
		$this->db->where('sale_id', $sale_id);

		return ($this->db->get()->num_rows()==1);
	}

	public function update($sale_id, $sale_data, $payments)
	{
		$this->db->where('sale_id', $sale_id);
		$success = $this->db->update('sales', $sale_data);

		// touch payment only if update sale is successful and there is a payments object otherwise the result would be to delete all the payments associated to the sale
		if($success && !empty($payments))
		{
			//Run these queries as a transaction, we want to make sure we do all or nothing
			$this->db->trans_start();
			
			// first delete all payments
			$this->db->delete('sales_payments', array('sale_id' => $sale_id));

			// add new payments
			foreach($payments as $payment)
			{
				$sales_payments_data = array(
					'sale_id' => $sale_id,
					'payment_type' => $payment['payment_type'],
					'payment_amount' => $payment['payment_amount']
				);

				$success = $this->db->insert('sales_payments', $sales_payments_data);
			}
			
			$this->db->trans_complete();
			
			$success &= $this->db->trans_status();
		}
		
		return $success;
	}

	public function save($items, $customer_id, $seller_id, $employee_id, $comment, $invoice_number, $payments, $comment2,$sale_id = FALSE)
	{
		if(count($items) == 0)
		{
			return -1;
		}


		$person_id = $this->Employee->get_logged_in_employee_info()->person_id;
		$habilitacion_caja = $this->Sale->get_habilitacion_caja($person_id);
		$mode =  $this->sale_lib->get_mode();
		$ticket = $this->get_next_ticket($habilitacion_caja);
		$sales_data = array(
			'sale_time'		 => date('Y-m-d H:i:s'),
			'customer_id'	 => $this->Customer->exists($customer_id) ? $customer_id : 5,
			'employee_id'	 => $employee_id,
			'comment'		 => $comment,
			'invoice_number' => $invoice_number,
			'seller_id'	 	 => $this->Employee->exists($seller_id) ? $seller_id : null,
			'caja_id'	 	 => $habilitacion_caja,
			'comment2'	 	 => $comment2,
			'mode'	 	 => $mode,
			'ticket'	 	 => $ticket
		);

		// Run these queries as a transaction, we want to make sure we do all or nothing
		$this->db->trans_start();

		$this->db->insert('sales', $sales_data);
		$sale_id = $this->db->insert_id();

		$efectiv = 0;
		$no_efectivo = 0;
		foreach($payments as $payment_id=>$payment)
		{
			if( substr( $payment['payment_type'], 0, strlen( $this->lang->line('sales_giftcard') ) ) == $this->lang->line('sales_giftcard') )
			{
				// We have a gift card and we have to deduct the used value from the total value of the card.
				$splitpayment = explode( ':', $payment['payment_type'] );
				$cur_giftcard_value = $this->Giftcard->get_giftcard_value( $splitpayment[1] );
				$this->Giftcard->update_giftcard_value( $splitpayment[1], $cur_giftcard_value - $payment['payment_amount'] );
			}

			if ($payment['payment_type']!='Efectivo') 
			{
				$sales_payments_data = array(
				'sale_id'		 => $sale_id,
				'payment_type'	 => $payment['payment_type'],
				'payment_amount' => $payment['payment_amount']
				);
				$this->db->insert('sales_payments', $sales_payments_data);
				$no_efectivo = $no_efectivo + ($payment['payment_amount']);
			}
			else
			{
				$efectiv = $efectiv + ($payment['payment_amount']);
			}
		}
        
        $suma=0;
        $total_importe = 0;
		foreach($items as $line=>$item)
		{
			$cur_item_info = $this->Item->get_info($item['item_id']);

			$sales_items_data = array(
				'sale_id'			=> $sale_id,
				'item_id'			=> $item['item_id'],
				'line'				=> $item['line'],
				'description'		=> character_limiter($item['description'], 30),
				'serialnumber'		=> character_limiter($item['serialnumber'], 30),
				'quantity_purchased'=> $item['quantity'],
				'discount_percent'	=> $item['discount'],
				'item_cost_price'	=> $cur_item_info->cost_price,
				'item_unit_price'	=> $item['price'],
				'item_location'		=> $item['item_location']
			);
			
			$total_importe = $total_importe + ($item['quantity']*($item['price']-($item['price']*$item['discount']/100)));

            $suma=$suma+($item['quantity']*$item['price']);
            
			$this->db->insert('sales_items', $sales_items_data);

			// Update stock quantity
			$item_quantity = $this->Item_quantity->get_item_quantity($item['item_id'], $item['item_location']);

			/*VERIFICAR SI EL ARTICULO TIENE PACK ASOCIADO*/
			/*LUEGO INSERTAR INVENTARIO Y MODIFICAR STOCK*/
			$items_pack= $this->Item->get_pack_items($item['item_id']);
			$contador_mat_pri = 0;
			$contador_mat_pri=count($items_pack);
			//echo "mat ".$contador_mat_pri;
			//die();
			if ($contador_mat_pri==0) {
				# code...
			
			$this->Item_quantity->save(array('quantity'		=> $item_quantity->quantity - $item['quantity'],
                                              'item_id'		=> $item['item_id'],
                                              'location_id'	=> $item['item_location']), $item['item_id'], $item['item_location']);

			}

			// if an items was deleted but later returned it's restored with this rule
			if($item['quantity'] < 0)
			{
				$this->Item->undelete($item['item_id']);
			}
											  
			// Inventory Count Details
			$trans_quantity = -$item['quantity'];
			if ($contador_mat_pri>0) {
				$trans_quantity = 0;
			}
			$sale_remarks = 'POS '.$sale_id;
			$inv_data = array(
				'trans_date'		=> date('Y-m-d H:i:s'),
				'trans_items'		=> $item['item_id'],
				'trans_user'		=> $employee_id,
				'trans_location'	=> $item['item_location'],
				'trans_comment'		=> $sale_remarks,
				'trans_inventory'	=> $trans_quantity
			);
			$this->Inventory->insert($inv_data);

			$customer = $this->Customer->get_info($customer_id);
 			if($customer_id == -1 || $customer->taxable)
 			{
				foreach($this->Item_taxes->get_info($item['item_id']) as $row)
				{
					$this->db->insert('sales_items_taxes', array(
						'sale_id' 	=> $sale_id,
						'item_id' 	=> $item['item_id'],
						'line'      => $item['line'],
						'name'		=> $row['name'],
						'percent' 	=> $row['percent']
					));
				}
			}

			/*VERIFICAR SI EL ARTICULO TIENE PACK ASOCIADO*/
			/*LUEGO INSERTAR INVENTARIO Y MODIFICAR STOCK*/
			
			foreach($items_pack as $itemp)
			{

				//ACTUALIZA STOCK
				$stock = $this->Item->get_stock_item_loc($itemp->item_id_item,$item['item_location']);
				$item_data = array(
				'quantity' => $stock-($item['quantity']*$itemp->quantity)
				);
				$this->db->where('item_id', $itemp->item_id_item);
				$this->db->where('location_id', $item['item_location']);
				$success1p = $this->db->update('ospos_item_quantities', $item_data);

				//ACTUALIZA AUDITORIA

				$inv_datap = array(
					'trans_date'		=> date('Y-m-d H:i:s'),
					'trans_items'		=> $itemp->item_id_item,
					'trans_user'		=> $employee_id,
					'trans_location'	=> $item['item_location'],
					'trans_comment'		=> $sale_remarks,
					'trans_inventory'	=> $item['quantity']*$itemp->quantity*-1
				);
				$this->Inventory->insert($inv_datap);

			}
			/*FIN DE PACK */

		}

		//Pago efectivo
		$efectivo = (abs($total_importe)-abs($no_efectivo));
		if ( $efectivo > 0) 
		{	
			$tipo_p = 'Efectivo';
			if ($mode=='return') 
			{
				$efectivo = $efectivo *-1;
				$tipo_p = 'Nota de Credito';
			}
			$sales_payments_data_e = array(
					'sale_id'		 => $sale_id,
					'payment_type'	 => $tipo_p,
					'payment_amount' => $efectivo
					);
			$this->db->insert('sales_payments', $sales_payments_data_e);
		}

		if (strlen($invoice_number)>0) 
			{
				// code...
			
			$item_data_tim = array(
				'value' => $invoice_number
				);
			$this->db->where('key', 'ultima_factura');
			$success_tim = $this->db->update('ospos_app_config', $item_data_tim);
			}
		
		$this->db->trans_complete();
		
		if($this->db->trans_status() === FALSE)
		{
			return -1;
		}
		
		return $sale_id;
	}

	public function delete_list($sale_ids, $employee_id, $update_inventory = TRUE) 
	{
		$result = TRUE;

		foreach($sale_ids as $sale_id)
		{
			$result &= $this->delete($sale_id, $employee_id, $update_inventory);
		}

		return $result;
	}

	public function delete($sale_id, $employee_id, $update_inventory = TRUE) 
	{
		// start a transaction to assure data integrity
		$this->db->trans_start();

		// first delete all payments
		$this->db->delete('sales_payments', array('sale_id' => $sale_id));
		// then delete all taxes on items
		$this->db->delete('sales_items_taxes', array('sale_id' => $sale_id));

		if($update_inventory)
		{
			// defect, not all item deletions will be undone??
			// get array with all the items involved in the sale to update the inventory tracking
			$items = $this->get_sale_items($sale_id)->result_array();
			foreach($items as $item)
			{
				/*VERIFICAR SI EL ARTICULO TIENE PACK ASOCIADO*/
				/*LUEGO INSERTAR INVENTARIO Y MODIFICAR STOCK*/
				$items_pack= $this->Item->get_pack_items($item['item_id']);
				$contador_mat_pri = 0;
				$contador_mat_pri=count($items_pack);
				$trans_quantity = $item['quantity_purchased'];
				if ($contador_mat_pri>0) 
				{
					$trans_quantity = 0;
				}


				// create query to update inventory tracking
				$inv_data = array(
					'trans_date'      => date('Y-m-d H:i:s'),
					'trans_items'     => $item['item_id'],
					'trans_user'      => $employee_id,
					'trans_comment'   => 'Deleting sale ' . $sale_id,
					'trans_location'  => $item['item_location'],
					'trans_inventory' => $trans_quantity
				);
				// update inventory
				$this->Inventory->insert($inv_data);

				// update quantities
				if ($contador_mat_pri==0) 
				{
						$this->Item_quantity->change_quantity($item['item_id'], $item['item_location'], $item['quantity_purchased']);
				}

				/*VERIFICAR SI EL ARTICULO TIENE PACK ASOCIADO*/
				/*LUEGO INSERTAR INVENTARIO Y MODIFICAR STOCK*/
			
				foreach($items_pack as $itemp)
				{

					//ACTUALIZA STOCK
					$stock = $this->Item->get_stock_item_loc($itemp->item_id_item,$item['item_location']);
					$item_data = array(
					'quantity' => $stock+($item['quantity_purchased']*$itemp->quantity)
					);
					$this->db->where('item_id', $itemp->item_id_item);
					$this->db->where('location_id', $item['item_location']);
					$success1p = $this->db->update('ospos_item_quantities', $item_data);

					//ACTUALIZA AUDITORIA
					$inv_datap = array(
						'trans_date'		=> date('Y-m-d H:i:s'),
						'trans_items'		=> $itemp->item_id_item,
						'trans_user'		=> $employee_id,
						'trans_location'	=> $item['item_location'],
						'trans_comment'		=> 'Deleting sale ' . $sale_id,
						'trans_inventory'	=> $item['quantity_purchased']*$itemp->quantity
						);
					$this->Inventory->insert($inv_datap);
				}
				/*FIN DE PACK */				
			}
		}

		// delete all items
		$this->db->delete('sales_items', array('sale_id' => $sale_id));
		// delete sale itself
		$this->db->delete('sales', array('sale_id' => $sale_id));

		// execute transaction
		$this->db->trans_complete();
	
		return $this->db->trans_status();
	}

	public function get_sale_items($sale_id)
	{
		$this->db->from('sales_items');
		$this->db->where('sale_id', $sale_id);
		$this->db->order_by('line', 'desc');
		return $this->db->get();
	}

	public function get_sale_payments($sale_id)
	{
		$this->db->from('sales_payments');
		$this->db->where('sale_id', $sale_id);

		return $this->db->get();
	}

	public function get_payment_options($giftcard = TRUE)
	{
		$payments = array();
		
		if($this->config->item('payment_options_order') == 'debitcreditcash')
		{
			$payments[$this->lang->line('sales_debit')] = $this->lang->line('sales_debit');
			$payments[$this->lang->line('sales_credit')] = $this->lang->line('sales_credit');
			$payments[$this->lang->line('sales_cash')] = $this->lang->line('sales_cash');
			$payments['Transferencia'] = "Transferencia";
		}
		elseif($this->config->item('payment_options_order') == 'debitcashcredit')
		{
			$payments[$this->lang->line('sales_debit')] = $this->lang->line('sales_debit');
			$payments[$this->lang->line('sales_cash')] = $this->lang->line('sales_cash');
			$payments[$this->lang->line('sales_credit')] = $this->lang->line('sales_credit');
			$payments['Transferencia'] = "Transferencia";
		}
		else // default: if($this->config->item('payment_options_order') == 'cashdebitcredit')
		{
			$payments[$this->lang->line('sales_cash')] = $this->lang->line('sales_cash');
			$payments[$this->lang->line('sales_debit')] = $this->lang->line('sales_debit');
			$payments[$this->lang->line('sales_credit')] = $this->lang->line('sales_credit');
			$payments['Transferencia'] = "Transferencia";
		}

		//$payments[$this->lang->line('sales_check')] = $this->lang->line('sales_check');
		$payments['Giro'] = "Giro";
		$payments['Pedidos Ya'] = "Pedidos Ya";
		$payments['Monchis'] = "Monchis";

		/*if($giftcard)
		{
			$payments[$this->lang->line('sales_giftcard')] = $this->lang->line('sales_giftcard');
		}*/

		return $payments;
	}

	public function get_customer($sale_id)
	{
		$this->db->from('sales');
		$this->db->where('sale_id', $sale_id);

		return $this->Customer->get_info($this->db->get()->row()->customer_id);
	}

	public function get_employee($sale_id)
	{
		$this->db->from('sales');
		$this->db->where('sale_id', $sale_id);

		return $this->Employee->get_info($this->db->get()->row()->employee_id);
	}


	public function get_seller($sale_id)
	{
		$this->db->from('sales');
		$this->db->where('sale_id', $sale_id);

		return $this->Employee->get_info($this->db->get()->row()->seller_id);
	}

	public function check_invoice_number_exists($invoice_number, $sale_id = '-1')
	{
		$invoice_number = '-99999999999';
		$this->db->from('sales');
		$this->db->where('invoice_number', $invoice_number);
		if(!empty($sale_id))
		{
			$this->db->where('sale_id !=', $sale_id);
		}
		
		return ($this->db->get()->num_rows() == 1);
	}

	public function get_giftcard_value($giftcardNumber)
	{
		if(!$this->Giftcard->exists($this->Giftcard->get_giftcard_id($giftcardNumber)))
		{
			return 0;
		}
		
		$this->db->from('giftcards');
		$this->db->where('giftcard_number', $giftcardNumber);

		return $this->db->get()->row()->value;
	}

	//We create a temp table that allows us to do easy report/sales queries
	public function create_temp_table(array $inputs)
	{
		if($this->config->item('tax_included'))
		{
			$sale_total = '(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100))';
			$sale_subtotal = '(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100) * (100 / (100 + SUM(sales_items_taxes.percent))))';
			$sale_tax = '(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100) * (1 - 100 / (100 + SUM(sales_items_taxes.percent))))';
		}
		else
		{
			$sale_total = '(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100) * (1 + (SUM(sales_items_taxes.percent) / 100)))';
			$sale_subtotal = '(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100))';
			$sale_tax = '(sales_items.item_unit_price * sales_items.quantity_purchased * (1 - sales_items.discount_percent / 100) * (SUM(sales_items_taxes.percent) / 100))';
		}

		$sale_cost  = '(sales_items.item_cost_price * sales_items.quantity_purchased)';

		$decimals = totals_decimals();

		if(empty($inputs['sale_id']))
		{
			$where = 'WHERE DATE(sales.sale_time) BETWEEN ' . $this->db->escape($inputs['start_date']) . ' AND ' . $this->db->escape($inputs['end_date']);
		}
		else
		{
			$where = 'WHERE sales.sale_id = ' . $this->db->escape($inputs['sale_id']);
		}

		// create a temporary table to contain all the payment types and amount
		$this->db->query('CREATE TEMPORARY TABLE IF NOT EXISTS ' . $this->db->dbprefix('sales_payments_temp') . 
			' (PRIMARY KEY(sale_id), INDEX(sale_id))
			(
				SELECT payments.sale_id AS sale_id, 
					IFNULL(SUM(payments.payment_amount), 0) AS sale_payment_amount,
					GROUP_CONCAT(CONCAT(payments.payment_type, " ", payments.payment_amount) SEPARATOR ", ") AS payment_type
				FROM ' . $this->db->dbprefix('sales_payments') . ' AS payments
				INNER JOIN ' . $this->db->dbprefix('sales') . ' AS sales
					ON sales.sale_id = payments.sale_id
				' . "
				$where
				" . '
				GROUP BY payments.sale_id
			)'
		);

		$this->db->query('CREATE TEMPORARY TABLE IF NOT EXISTS ' . $this->db->dbprefix('sales_items_temp') . 
			' (INDEX(sale_date), INDEX(sale_id))
			(
				SELECT
					DATE(sales.sale_time) AS sale_date,
					sales.sale_time,
					sales.sale_id,
					sales.comment,
					sales.invoice_number,
					sales.customer_id,
					sales.ticket,
					CONCAT(customer_p.first_name, " ", customer_p.last_name) AS customer_name,
					customer_p.first_name AS customer_first_name,
					customer_p.last_name AS customer_last_name,
					customer_p.email AS customer_email,
					customer_p.comments AS customer_comments, 
					customer.company_name AS customer_company_name,
					sales.employee_id,
					CONCAT(employee.first_name, " ", employee.last_name) AS employee_name,
					items.item_id,
					items.name,
					items.category,
					items.supplier_id,
					sales_items.quantity_purchased,
					sales_items.item_cost_price,
					sales_items.item_unit_price,
					sales_items.discount_percent,
					sales_items.line,
					sales_items.serialnumber,
					sales_items.item_location,
					sales_items.description,
					payments.payment_type,
					payments.sale_payment_amount,
					IFNULL(SUM(sales_items_taxes.percent), 0) AS item_tax_percent,
					' . "
					ROUND($sale_subtotal, $decimals) AS subtotal,
					IFNULL(ROUND($sale_tax, $decimals), 0) AS tax,
					IFNULL(ROUND($sale_total, $decimals), ROUND($sale_subtotal, $decimals)) AS total,
					ROUND($sale_cost, $decimals) AS cost,
					ROUND($sale_total  - $sale_cost, $decimals) AS profit
					" . '
				FROM ' . $this->db->dbprefix('sales_items') . ' AS sales_items
				INNER JOIN ' . $this->db->dbprefix('sales') . ' AS sales
					ON sales_items.sale_id = sales.sale_id
				INNER JOIN ' . $this->db->dbprefix('items') . ' AS items
					ON sales_items.item_id = items.item_id
				LEFT OUTER JOIN ' . $this->db->dbprefix('sales_payments_temp') . ' AS payments
					ON sales_items.sale_id = payments.sale_id		
				LEFT OUTER JOIN ' . $this->db->dbprefix('suppliers') . ' AS supplier
					ON items.supplier_id = supplier.person_id
				LEFT OUTER JOIN ' . $this->db->dbprefix('people') . ' AS customer_p
					ON sales.customer_id = customer_p.person_id
				LEFT OUTER JOIN ' . $this->db->dbprefix('customers') . ' AS customer
					ON sales.customer_id = customer.person_id
				LEFT OUTER JOIN ' . $this->db->dbprefix('people') . ' AS employee
					ON sales.employee_id = employee.person_id
				LEFT OUTER JOIN ' . $this->db->dbprefix('sales_items_taxes') . ' AS sales_items_taxes
					ON sales_items.sale_id = sales_items_taxes.sale_id AND sales_items.item_id = sales_items_taxes.item_id AND sales_items.line = sales_items_taxes.line
				' . "
				$where
				" . '
				GROUP BY sales.sale_id, items.item_id, sales_items.line
			)'
		);

		// drop the temporary table to contain memory consumption as it's no longer required
		$this->db->query('DROP TEMPORARY TABLE IF EXISTS ' . $this->db->dbprefix('sales_payments_temp'));
	}

	public function get_next_invoice_number()
	{	
		/*
		$query = $this->db->query("select cast(ospos_sales.invoice_number as unsigned integer) as num from ospos_sales where date(sale_time)>='2022-12-06' order by num desc limit 1");
		$return = 0;
		foreach ($query->result_array() as $row) {
			$return = $row['num'];
		}*/
		$ultima_factura= $this->config->item('ultima_factura');
		$return = $ultima_factura + 1;
		//echo $return;
		//die();
		return $return;
	}

	public function get_habilitacion_caja($person_id)
	{	
		$query = $this->db->query("select ospos_sales_caja.sale_caja_id from ospos_sales_caja where ospos_sales_caja.sale_caja_cierre_time is null and ospos_sales_caja.person_id=".$person_id." limit 1");
		$return = 0;
		foreach ($query->result_array() as $row) {
			$return = $row['sale_caja_id'];
		}
		
		
		//echo $return;
		//die();
		return $return;
	}

	public function get_caja_chica($sale_caja_id)
	{	
		$query = $this->db->query("select ospos_sales_caja.caja_chica from ospos_sales_caja where ospos_sales_caja.sale_caja_id=".$sale_caja_id ." limit 1");
		$return = 0;
		foreach ($query->result_array() as $row) {
			$return = $row['caja_chica'];
		}
		
		
		//echo $return;
		//die();
		return $return;
	}

	public function get_caja_apertura($sale_caja_id)
	{	
		$query = $this->db->query("select ospos_sales_caja.sale_caja_apertura_time from ospos_sales_caja where ospos_sales_caja.sale_caja_id=".$sale_caja_id ." limit 1");
		$return = '';
		foreach ($query->result_array() as $row) {
			$return = $row['sale_caja_apertura_time'];
		}
		
		
		//echo $return;
		//die();
		return $return;
	}

		
	public function get_sale_total($habilitacion_caja)
	{	
		$query = $this->db->query("select sum(i.quantity_purchased*(i.item_unit_price-(i.item_unit_price*i.discount_percent/100))) sale_total
					from ospos_sales_items i,ospos_sales s
					where i.sale_id = s.sale_id
					and s.caja_id = '".$habilitacion_caja."' limit 1");
		$return = 0;
		foreach ($query->result_array() as $row) {
			$return = $row['sale_total'];
		}
		
		
		//echo $return;
		//die();
		return $return;
	}

	/* Get lista de apertura y cierres de caja*/
	public function get_caja_person_list($person_id,$fecha_ini,$fecha_fin)
	{


		$sql="select c.sale_caja_apertura_time,
    	c.sale_caja_cierre_time,
    	c.person_id,
    	c.sale_caja_id,
    	c.caja_chica,
    	c.sale_total,
    	c.caja_cierre,
    	p.first_name,
    	p.last_name
		from ospos_sales_caja c,ospos_people p
		where date(c.sale_caja_apertura_time) between date(?) and date(?)
		and p.person_id=c.person_id
		and EXISTS (
			SELECT 1 FROM ospos_permissions p,ospos_grants g
			WHERE p.module_id='sales'
			
			AND p.permission_id=g.permission_id
			AND g.person_id=c.person_id)
		";		

		//echo $sql;
		$query=$this->db->query($sql,array($fecha_ini,$fecha_fin));
		$r=$query->result();
		return $r;
	}

	/* Get lista de apertura y cierres de caja*/
	public function get_caja_list($category)
	{
		$sql="select ospos_sales_caja.sale_caja_apertura_time,
    	ospos_sales_caja.sale_caja_cierre_time,
    	ospos_sales_caja.person_id,
    	ospos_sales_caja.sale_caja_id,
    	ospos_sales_caja.caja_chica,
    	ospos_sales_caja.sale_total,
    	ospos_sales_caja.caja_cierre
		from openventas.ospos_sales_caja
		where date(ospos_sales_caja.sale_caja_apertura_time) between date(?) and date(?)
		limit 10000";		

		$query=$this->db->query($sql,array($category));
		$r=$query->result();
		return $r;
	}

	/* Get lista de ventas */
	public function get_sale_person_list($person_id,$fecha_ini,$fecha_fin)
	{
		$sql="select ospos_sales.sale_time,
    	ospos_sales.employee_id,
    	ospos_sales.invoice_number,
    	ospos_sales.sale_id,
        ospos_sales.customer_id,
    	sum(ospos_sales_items.quantity_purchased*(ospos_sales_items.item_unit_price-(ospos_sales_items.item_unit_price*ospos_sales_items.discount_percent/100))) sale_total
		from ospos_sales,ospos_sales_items
		where ospos_sales.employee_id = ?
        and ospos_sales_items.sale_id=ospos_sales.sale_id
		and date(ospos_sales.sale_time) between date(?) and date(?)
        group by ospos_sales.sale_id
        order by ospos_sales.sale_id asc";		

		$query=$this->db->query($sql,array($person_id,$fecha_ini,$fecha_fin));
		$r=$query->result();
		return $r;
	}

	/* Get lista de detalle de ventas */
	public function get_sale_list_det($sale_id)
	{
		$sql="select ospos_sales.sale_time,
    	ospos_sales.employee_id,
    	ospos_sales.invoice_number,
    	ospos_sales.sale_id,
        ospos_sales.customer_id,
    	ospos_sales_items.item_id,
        ospos_sales_items.item_unit_price,
        ospos_sales_items.quantity_purchased,
        ospos_sales_items.line,
        ospos_items.name,
        ospos_items.item_number,
        ospos_sales_items.quantity_purchased*(ospos_sales_items.item_unit_price-(ospos_sales_items.item_unit_price*ospos_sales_items.discount_percent/100)) item_total
		from ospos_sales,ospos_sales_items,ospos_items
		where ospos_sales.sale_id = ?
        and ospos_sales_items.sale_id=ospos_sales.sale_id
        and ospos_sales_items.item_id=ospos_items.item_id
        order by ospos_sales.sale_id, ospos_sales_items.line asc";		

		$query=$this->db->query($sql,array($sale_id));
		$r=$query->result();
		return $r;
	}

	/* Get lista de cierre administrativo */
	public function get_balance_cierre_admin($fecha_ini,$fecha_fin)
	{
		$sql="
		select sale_time,tipo,sale_total,cost_total,ganancia_total from (
		select date(ospos_sales.sale_time) sale_time,
		'VENTAS' tipo,
    	sum(ospos_sales_items.quantity_purchased*(ospos_sales_items.item_unit_price-(ospos_sales_items.item_unit_price*ospos_sales_items.discount_percent/100))) sale_total,
        sum(ospos_sales_items.quantity_purchased* ospos_sales_items.item_cost_price) cost_total,
        sum(ospos_sales_items.quantity_purchased*(ospos_sales_items.item_unit_price-(ospos_sales_items.item_unit_price*ospos_sales_items.discount_percent/100))) -
        sum(ospos_sales_items.quantity_purchased* ospos_sales_items.item_cost_price) ganancia_total
		from ospos_sales,ospos_sales_items
		where ospos_sales_items.sale_id=ospos_sales.sale_id
		and date(ospos_sales.sale_time) between date(?) and date(?)
        group by date(ospos_sales.sale_time)
union all
select date(ospos_receivings.receiving_time),
		'GASTOS' tipo,
		0 ,
        0 ,
        -1 * sum(ospos_receivings_items.quantity_purchased * ospos_receivings_items.item_unit_price)
from ospos_receivings ,ospos_receivings_items
where ospos_receivings.receiving_id = ospos_receivings_items.receiving_id
and ospos_receivings_items.item_cost_price = 0
and date(ospos_receivings.receiving_time) between date(?) and date(?)
group by date(ospos_receivings.receiving_time)
union all
select date(ospos_receivings.receiving_time),
		'BAJA MERCADERIA' tipo,
		0 ,
        0 ,
        sum(ospos_receivings_items.quantity_purchased * ospos_receivings_items.item_unit_price)
from ospos_receivings ,ospos_receivings_items
where ospos_receivings.receiving_id = ospos_receivings_items.receiving_id
and (ospos_receivings_items.item_cost_price * ospos_receivings_items.quantity_purchased) < 0
and date(ospos_receivings.receiving_time) between date(?) and date(?)
group by date(ospos_receivings.receiving_time)
)q
where q.ganancia_total<> 0";		

		$query=$this->db->query($sql,array($fecha_ini,$fecha_fin,$fecha_ini,$fecha_fin,$fecha_ini,$fecha_fin));
		$r=$query->result();
		return $r;
	}

	public function get_libreta_total($person_id,$sale_caja_apertura_time)
	{	
		$query = $this->db->query("select sum(i.payment_amount) sale_total
					from ospos_sales_payments i,ospos_sales s
					where i.sale_id = s.sale_id
					and s.employee_id = ".$person_id." 
                    and i.payment_type = 'Libreta'
					and s.sale_time >= '".$sale_caja_apertura_time."' limit 1");
		$return = 0;
		foreach ($query->result_array() as $row) {
			$return = $row['sale_total'];
		}
		
		
		//echo $return;
		//die();
		return $return;
	}

	public function get_cobros_clientes($person_id,$sale_caja_apertura_time)
	{	
		$query = $this->db->query("select sum(i.payment_amount) sale_total
					from ospos_sales_payments_credit i
					where i.employee_id = ".$person_id." 
					and i.payment_time >= '".$sale_caja_apertura_time."' limit 1");
		$return = 0;
		foreach ($query->result_array() as $row) {
			$return = $row['sale_total'];
		}
		
		
		//echo $return;
		//die();
		return $return;
	}

	/*Restaurant Tables*/
	public function get_restaurant_tables()
	{
		$sql="select ospos_restaurant_tables.table_id,
    	ospos_restaurant_tables.description,
    	ospos_restaurant_tables.area,
    	ospos_restaurant_tables.status,
    	ospos_restaurant_tables.fila,
    	ospos_restaurant_tables.columna
		from ospos_restaurant_tables";		

		$query=$this->db->query($sql);
		$r=$query->result();
		return $r;
	}

	public function get_restaurant_table_data_row($table_id)
	{	
		$sql="select ospos_restaurant_tables.table_id,
    	ospos_restaurant_tables.description,
    	ospos_restaurant_tables.area,
    	ospos_restaurant_tables.status
		from ospos_restaurant_tables
		where ospos_restaurant_tables.table_id=?
		limit 1";		

		$query=$this->db->query($sql,$table_id);
		$r=$query->result();
		return $r;
	}

	/*REPORTE BALANCE VENTAS Y PRODUCCION*/
	public function get_sales_item($item_id,$fecha_ini,$fecha_fin)
	{
		$sql="select date(s.sale_time) fecha,
			sum(si.quantity_purchased) cantidad_vendida, sum(item_cost_price*si.quantity_purchased) costo,sum(item_unit_price*si.quantity_purchased) venta
			from ospos_sales s,ospos_sales_items si
			where si.item_id=?
			and s.sale_id=si.sale_id
			and date(s.sale_time) between (?) and (?)
			group by date(s.sale_time)";		

		$query=$this->db->query($sql,array($item_id,$fecha_ini,$fecha_fin));
		$r=$query->result();
		return $r;
	}

	public function get_production_finished_item($item_id,$fecha_ini,$fecha_fin)
	{
		$sql="select date(p.production_time) fecha,
			sum(pf.quantity) cantidad_producida,sum(pf.cost_price*pf.quantity) total 
			from ospos_productions p,ospos_productions_finished pf
			where pf.item_id=?
			and p.production_id=pf.production_id
			and date(p.production_time) between (?) and (?)
			group by date(p.production_time)";		

		$query=$this->db->query($sql,array($item_id,$fecha_ini,$fecha_fin));
		$r=$query->result();
		return $r;
	}

	public function get_production_items_item($item_id,$fecha_ini,$fecha_fin)
	{
		$sql="select date(p.production_time) fecha,i.name,
			sum(pi.quantity) cantidad_utilizada,sum(pi.quantity*pi.cost_price) total
			from ospos_productions p,ospos_productions_finished pf,ospos_productions_items pi,ospos_items i
			where pf.item_id=?
			and p.production_id=pf.production_id
			and p.production_id=pi.production_id
			and pi.item_id=i.item_id
			and date(p.production_time) between (?) and (?)
			group by date(p.production_time),i.name";		

		$query=$this->db->query($sql,array($item_id,$fecha_ini,$fecha_fin));
		$r=$query->result();
		return $r;
	}

	public function get_production_employee_item($item_id,$fecha_ini,$fecha_fin)
	{
		$sql="select date(p.production_time) fecha,concat(pl.first_name,' ',pl.last_name) name
			from ospos_productions p,ospos_productions_finished pf,
			ospos_productions_employees pe,ospos_people pl
			where pf.item_id=?
			and p.production_id=pf.production_id
			and p.production_id=pe.production_id
			and pe.employee_id=pl.person_id
			and date(p.production_time) between (?) and (?)
			group by date(p.production_time),pe.employee_id";		

		$query=$this->db->query($sql,array($item_id,$fecha_ini,$fecha_fin));
		$r=$query->result();
		return $r;
	}
	/*FIN REPORTE BALANCE VENTAS Y PRODUCCION*/

	public function get_next_turno()
	{
		$this->db->select_max('ospos_sales.comment');
		$this->db->from('ospos_sales');
		$this->db->limit(1);

		return $this->db->get()->row()->comment+1;
	}

	public function get_sale_estados($caja_id)
	{

		$sql="SELECT s.sale_id,s.comment,si.quantity_purchased , i.name,s.sale_time,p.first_name,s.estado,s.comment2
			FROM ospos_sales s
			left join ospos_sales_items si
			on s.sale_id=si.sale_id
			left join ospos_items i
			on si.item_id=i.item_id
			left join ospos_people p
			on s.customer_id=p.person_id
			where s.estado in ('F','I')
			and s.caja_id=?
			";	
		//echo "in 1 ";
		$query=$this->db->query($sql,array($caja_id));
		//echo "in 2 ";
		$r=$query->result();
		//echo "in 3 ";
		return $r;
	}

	public function get_detalle_ventas($zona,$seller_id,$fecha_ini,$fecha_fin,$customer_id,$factura,$tipo,$ticket=0)
	{
		$uno=1;
		//echo "param ".$zona."-".$seller_id."-".$fecha_ini."-".$fecha_fin."-".$customer_id."-".$factura."-".$tipo;
		if ($factura==0) 
		{
		
			if ($ticket==0) 
			{
				$mode='return';
				if ($tipo=='ventas') 
				{
					$mode='sale';
				}
				$sql="SELECT s.sale_id,s.invoice_number,p.first_name,p.last_name,p.address_1,p.address_2,p.zip,si.item_id,i.item_number,si.quantity_purchased quantity ,i.name,si.item_unit_price precio,si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100)) total,i.custom10 cod_interno,s.sale_time,si.discount_percent,s.mode,si.line,si.item_location
				FROM ospos_sales_items si, ospos_sales s
				LEFT JOIN ospos_people p
				ON s.customer_id=p.person_id
				,ospos_items i
				WHERE s.sale_id=si.sale_id
				AND date(s.sale_time) BETWEEN date(?) AND date(?)
				and ((s.seller_id = ? and ? !=0) or (? =0))
				and ((p.zip = ? and ? !=0) or (? =0))
				and ((s.customer_id = ? and ? !=0) or (? =0))
				and s.mode=?
				AND si.item_id=i.item_id
				order by s.mode,s.sale_id desc
				";		

				//echo "in 1 ";
				$query=$this->db->query($sql,array($fecha_ini,$fecha_fin,$seller_id,$seller_id,$seller_id,$zona,$zona,$zona,$customer_id,$customer_id,$customer_id,$mode));
			}
			else
			{
				//echo "string2";
				$sql="SELECT s.sale_id,s.invoice_number,p.first_name,p.last_name,p.address_1,p.address_2,p.zip,si.item_id,i.item_number,si.quantity_purchased quantity ,i.name,si.item_unit_price precio,si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100)) total,i.custom10 cod_interno,s.sale_time,si.discount_percent,s.mode,si.line,si.item_location
				FROM ospos_sales_items si, ospos_sales s
				LEFT JOIN ospos_people p
				ON s.customer_id=p.person_id
				,ospos_items i
				WHERE s.sale_id=si.sale_id
				
				AND si.item_id=i.item_id
				and s.sale_id=?
				";		

				//echo "in 1 ";
				$query=$this->db->query($sql,array($ticket));
			}
		}
		else
		{
			//echo "string2";
			$sql="SELECT s.sale_id,s.invoice_number,p.first_name,p.last_name,p.address_1,p.address_2,p.zip,si.item_id,i.item_number,si.quantity_purchased quantity ,i.name,si.item_unit_price precio,si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100)) total,i.custom10 cod_interno,s.sale_time,si.discount_percent,s.mode,si.line,si.item_location
			FROM ospos_sales_items si, ospos_sales s
				LEFT JOIN ospos_people p
				ON s.customer_id=p.person_id
				,ospos_items i
				WHERE s.sale_id=si.sale_id
				
			
			AND si.item_id=i.item_id
			and s.invoice_number=?
			";		

			//echo "in 1 ";
			$query=$this->db->query($sql,array($factura));
		}
		//echo "in 2 ";
		$r=$query->result();
		//echo "in 3 ";
		return $r;
	}

	public function get_detalle_pedidos($zona,$seller_id,$fecha_ini,$fecha_fin,$customer_id,$tipo_fecha)
	{
		$uno=1;
		//echo "seller ".$seller_id." zona ".$zona." cus ".$customer_id;
		$sql="SELECT s.sale_id,s.invoice_number,p.first_name,p.last_name,p.address_1,p.address_2,p.zip,si.item_id,i.item_number,si.quantity_purchased quantity ,i.name,si.item_unit_price precio,si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100)) total,i.custom10 cod_interno,s.sale_time,si.discount_percent,s.fecha_entrega
			FROM ospos_sales_suspended_items si, ospos_sales_suspended s
			left join ospos_people p
			on s.customer_id=p.person_id
			,ospos_items i
			WHERE s.sale_id=si.sale_id
			AND date(s.sale_time) BETWEEN ? AND ?
			
			and ((s.seller_id = ? and ? !=0) or (? =0))
			and ((p.zip = ? and ? !=0) or (? =0))
			and ((s.customer_id = ? and ? !=0) or (? =0))
			AND si.item_id=i.item_id
			";	
		//echo $sql;
		if ($tipo_fecha=='fecha_entrega') 
		{
			$sql="SELECT s.sale_id,s.invoice_number,p.first_name,p.last_name,p.address_1,p.address_2,p.zip,si.item_id,i.item_number,si.quantity_purchased quantity ,i.name,si.item_unit_price precio,si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100)) total,i.custom10 cod_interno,s.sale_time,si.discount_percent,s.fecha_entrega
			FROM ospos_sales_suspended_items si, ospos_sales_suspended s
			left join ospos_people p
			on s.customer_id=p.person_id
			,ospos_items i
			WHERE s.sale_id=si.sale_id
			AND date(s.fecha_entrega) BETWEEN ? AND ?
	
			and ((s.seller_id = ? and ? !=0) or (? =0))
			and ((p.zip = ? and ? !=0) or (? =0))
			and ((s.customer_id = ? and ? !=0) or (? =0))
			AND si.item_id=i.item_id
			";	
		}
			

		//echo "in 1 ";
		$query=$this->db->query($sql,array($fecha_ini,$fecha_fin,$seller_id,$seller_id,$seller_id,$zona,$zona,$zona,$customer_id,$customer_id,$customer_id));
		//echo "in 2 ";
		$r=$query->result();
		//echo "in 3 ";
		return $r;
	}

	public function get_detalle_ventas_anuladas($zona,$seller_id,$fecha_ini,$fecha_fin,$customer_id)
	{
		$uno=1;
		$sql="SELECT s.sale_id,s.invoice_number,p.first_name,p.last_name,p.address_1,p.address_2,p.zip,si.item_id,i.item_number,si.quantity_purchased quantity ,i.name,si.item_unit_price precio,si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100)) total,i.custom10 cod_interno,s.sale_time,
			s.motivo_id,s.motivo_comment,si.discount_percent
			FROM ospos_sales_deleted_items si, ospos_sales_deleted s
			left join ospos_people p
			on s.customer_id=p.person_id
			,ospos_items i
			WHERE s.sale_id=si.sale_id
			AND date(s.sale_time) BETWEEN ? AND ?
			
			and ((s.seller_id = ? and ? !=0) or (? =0))
			and ((p.zip = ? and ? !=0) or (? =0))
			and ((s.customer_id = ? and ? !=0) or (? =0))
			AND si.item_id=i.item_id
			";		

		//echo "in 1 ";
		$query=$this->db->query($sql,array($fecha_ini,$fecha_fin,$seller_id,$seller_id,$seller_id,$zona,$zona,$zona,$customer_id,$customer_id,$customer_id));
		//echo "in 2 ";
		$r=$query->result();
		//echo "in 3 ";
		return $r;
	}

	public function get_sale($sale_id)
	{
		
		$sql="SELECT sale_time,customer_id,employee_id,comment,invoice_number,sale_id,seller_id,mode,caja_id,pedido_id
			FROM ospos_sales
			WHERE sale_id=?
			";		

		//echo "in 1 ";
		$query=$this->db->query($sql,array($sale_id));
		//echo "in 2 ";
		$r=$query->result();
		//echo "in 3 ";
		return $r;
	}

	public function get_sale_items_id($sale_id)
	{
		$uno=1;
		$sql="SELECT sale_id,item_id,description,serialnumber,line,quantity_purchased,item_cost_price,item_unit_price,discount_percent,item_location
			FROM ospos_sales_items s
			WHERE s.sale_id=?
			";		

		//echo "in 1 ";
		$query=$this->db->query($sql,array($sale_id));
		//echo "in 2 ";
		$r=$query->result();
		//echo "in 3 ";
		return $r;
	}

	public function get_next_ticket($caja_id)
	{	
		$query = $this->db->query("select max(s.ticket) ticket
					from ospos_sales s
					where s.caja_id = ".$caja_id." 
					");
		$return = 0;
		foreach ($query->result_array() as $row) {
			$return = $row['ticket'];
		}
		
		
		//echo $return;
		//die();
		return $return+1;
	}

	public function get_ticket($sale_id)
	{	
		$query = $this->db->query("select s.ticket
					from ospos_sales s
					where s.sale_id = ".$sale_id." 
					");
		$return = 0;
		foreach ($query->result_array() as $row) {
			$return = $row['ticket'];
		}
		
		
		//echo $return;
		//die();
		return $return;
	}

	//Reportes para contabilidad
	//Reporte ventas para contabilidad
	public function ventas_contable($fecha_ini,$fecha_fin,$mode)
	{

		$sql="SELECT 
date(s.sale_time) fecha,s.invoice_number factura,'' timbrado,'' timbrado_venc,p.address_2 ruc,concat(p.first_name,' ',p.last_name) persona,
			(select sum(si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100))) 
			from ospos_sales_items si,ospos_items_taxes i
			where si.sale_id=s.sale_id
			and si.item_id=i.item_id
			and i.percent=10) gravadas_10,
			(select sum(si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100))) 
			from ospos_sales_items si,ospos_items_taxes i
			where si.sale_id=s.sale_id
			and si.item_id=i.item_id
			and i.percent=5) gravadas_05,
			(select sum(si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100))) 
			from ospos_sales_items si,ospos_items_taxes i
			where si.sale_id=s.sale_id
			and si.item_id=i.item_id
			and i.percent=0) exentas,
			'GS' moneda,
			'CONTADO' condicion,
			'0' cuotas,
			'VENTA DE MERCADERÍAS GRAV. 10%' cuenta_10,
			'VENTA DE MERCADERÍAS GRAV. 05%' cuenta_05,
			'VENTAS DE MERCADERÍAS EXENTAS DEL IVA'cuenta_00,
			s.sale_id,
			e.first_name first_name_e,
			e.last_name last_name_e
			from ospos_sales s,ospos_people p,ospos_people e
			where s.customer_id=p.person_id
			
			and date(s.sale_time) BETWEEN ? AND ?
			and s.mode=?
			AND p.address_2!='44444401-7'
			and s.employee_id=e.person_id
			UNION all
			
			
			SELECT 
date(s.sale_time) fecha,s.invoice_number,'' timbrado,'' timbrado_venc,'44444401-7' ruc,'IMPORTES CONSOLIDADOS' persona,
			(select sum(si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100))) 
			from ospos_sales_items si,ospos_items_taxes i
			where si.sale_id=s.sale_id
			and si.item_id=i.item_id
			and i.percent=10) gravadas_10,
			(select sum(si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100))) 
			from ospos_sales_items si,ospos_items_taxes i
			where si.sale_id=s.sale_id
			and si.item_id=i.item_id
			and i.percent=5) gravadas_5,
			(select sum(si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100))) 
			from ospos_sales_items si,ospos_items_taxes i
			where si.sale_id=s.sale_id
			and si.item_id=i.item_id
			and i.percent=0) exentas,
			'GS' moneda,
			'CONTADO' condicion,
			'0' cuotas,
			'VENTA DE MERCADERÍAS GRAV. 10%' cuenta_10,
			'VENTA DE MERCADERÍAS GRAV. 05%' cuenta_05,
			'VENTAS DE MERCADERÍAS EXENTAS DEL IVA'cuenta_00,
			s.sale_id,
			e.first_name first_name_e,
			e.last_name last_name_e
			from ospos_sales s,ospos_people p,ospos_people e
			where s.customer_id=p.person_id
			
			and date(s.sale_time) BETWEEN ? AND ?
			and s.mode=?
			AND p.address_2='44444401-7'
			and s.employee_id=e.person_id
			order by 2
			";		
		//echo "in 1 ";
		$query=$this->db->query($sql,array($fecha_ini,$fecha_fin,$mode,$fecha_ini,$fecha_fin,$mode));
		//echo "in 2 ";
		$r=$query->result();
		//echo "in 3 ";
		return $r;
	}
	public function ventasanul_contable($fecha_ini,$fecha_fin)
	{

		$sql="select * from (SELECT 
date(s.sale_time) fecha,s.invoice_number factura,0 timbrado,0 timbrado_venc,p.address_2 ruc,concat(p.first_name,' ',p.last_name) persona,
			(select sum(si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100))) 
			from ospos_sales_deleted_items si,ospos_items_taxes i
			where si.sale_id=s.sale_id
			and si.item_id=i.item_id
			and i.percent=10) gravadas_10,
			(select sum(si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100))) 
			from ospos_sales_deleted_items si,ospos_items_taxes i
			where si.sale_id=s.sale_id
			and si.item_id=i.item_id
			and i.percent=5) gravadas_05,
			(select sum(si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100))) 
			from ospos_sales_deleted_items si,ospos_items_taxes i
			where si.sale_id=s.sale_id
			and si.item_id=i.item_id
			and i.percent=0) exentas,
			'GS' moneda,
			'CONTADO' condicion,
			'0' cuotas,
			'VENTA DE MERCADERÍAS GRAV. 10%' cuenta_10,
			'VENTA DE MERCADERÍAS GRAV. 05%' cuenta_05,
			'VENTAS DE MERCADERÍAS EXENTAS DEL IVA'cuenta_00,
			s.sale_id,
			s.employee_id,
			e.first_name first_name_e,
			e.last_name last_name_e,
			s.motivo_comment
			from ospos_sales_deleted s,ospos_people p,ospos_people e
			where s.customer_id=p.person_id
			
			and date(s.sale_time) BETWEEN ? AND ?
			
			AND p.address_2!='44444401-7'
			and s.employee_id=e.person_id
			UNION all
			
			
			SELECT 
date(s.sale_time) fecha,s.invoice_number,0 timbrado,0 timbrado_venc,'44444401-7' ruc,'IMPORTES CONSOLIDADOS' persona,
			(select sum(si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100))) 
			from ospos_sales_deleted_items si,ospos_items_taxes i
			where si.sale_id=s.sale_id
			and si.item_id=i.item_id
			and i.percent=10) gravadas_10,
			(select sum(si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100))) 
			from ospos_sales_deleted_items si,ospos_items_taxes i
			where si.sale_id=s.sale_id
			and si.item_id=i.item_id
			and i.percent=5) gravadas_5,
			(select sum(si.quantity_purchased*(si.item_unit_price-(si.item_unit_price*si.discount_percent/100))) 
			from ospos_sales_deleted_items si,ospos_items_taxes i
			where si.sale_id=s.sale_id
			and si.item_id=i.item_id
			and i.percent=0) exentas,
			'GS' moneda,
			'CONTADO' condicion,
			'0' cuotas,
			'VENTA DE MERCADERÍAS GRAV. 10%' cuenta_10,
			'VENTA DE MERCADERÍAS GRAV. 05%' cuenta_05,
			'VENTAS DE MERCADERÍAS EXENTAS DEL IVA'cuenta_00,
			s.sale_id,
			s.employee_id,
			e.first_name first_name_e,
			e.last_name last_name_e,
			s.motivo_comment
			from ospos_sales_deleted s,ospos_people p,ospos_people e
			where s.customer_id=p.person_id
			
			and date(s.sale_time) BETWEEN ? AND ?
			
			AND p.address_2='44444401-7'
			and s.employee_id=e.person_id
			)q order by 2
			";		
		//echo "in 1 ";
		$query=$this->db->query($sql,array($fecha_ini,$fecha_fin,$fecha_ini,$fecha_fin));
		//echo "in 2 ";
		$r=$query->result();
		//echo "in 3 ";
		return $r;
	}

	public function get_tipo_cobranza_caja($caja_id)
	{

		$sql="SELECT sum(p.payment_amount) payment_amount,p.payment_type
			FROM ospos_sales_payments p,ospos_sales s
			WHERE s.caja_id=?
			and s.sale_id = p.sale_id
			group by p.payment_type";
		//echo "in 1 ";
		$query=$this->db->query($sql,array($caja_id));
		//echo "in 2 ";
		$r=$query->result();
		//echo "in 3 ";
		return $r;
	}

	public function get_descuentos_caja($caja_id)
	{	
		$query = $this->db->query("select sum(si.quantity_purchased*((si.item_unit_price*si.discount_percent/100))) discount
					from ospos_sales s, ospos_sales_items si
					where s.caja_id = ".$caja_id." 
					and s.sale_id = si.sale_id
					");
		$return = 0;
		foreach ($query->result_array() as $row) {
			$return = $row['discount'];
		}
		
		
		//echo $return;
		//die();
		return $return;
	}

	public function get_comment($sale_id)
	{	
		$query = $this->db->query("select s.comment
					from ospos_sales s
					where s.sale_id = ".$sale_id." 
					");
		$return = 0;
		foreach ($query->result_array() as $row) {
			$return = $row['comment'];
		}
		
		
		//echo $return;
		//die();
		return $return;
	}

}
?>
